@@ -1,5 +1,5 @@
 <?php
-/* $Id: azerbaijani-utf-8.inc.php,v 2.118.2.3 2006/03/23 17:42:09 lem9 Exp $ */
+/* $Id: azerbaijani-utf-8.inc.php,v 2.143 2006/08/09 12:55:35 lem9 Exp $ */
 
 // tercümedeki eksiklerimi ve ya sehv olduğunu düşündüyünüz yerleri shehriyari@trcomm.net adresine göndere bilersiniz...
 // Şehriyar İmanov 30 Avqust 2003... Shehi
@@ -7,8 +7,6 @@
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
@@ -28,11 +26,9 @@ $strAction = 'Fealiyyetler';
 $strAddAutoIncrement = 'AUTO_INCREMENT deyeri elave et';
 $strAddDeleteColumn = 'Sahe Sütunlarını Elave Et/Sil';
 $strAddDeleteRow = 'Kriteria Setirlerini Elave Et/Sil';
-$strAddDropDatabase = 'DROP DATABASE elave et';
 $strAddedColumnComment = 'Bu sütun üçün qısa izahat elave edildi';
 $strAddedColumnRelation = 'Sütun üçün elaqe elave edildi';
 $strAddHeaderComment = 'Başlığa xülase me\'lumatı elave et (\\n yeni setire keçir)';
-$strAddIfNotExists = 'IF NOT EXISTS elave et';
 $strAddIntoComments = 'Xülaseye elave et';
 $strAddNewField = 'Yeni sahe elave et';
 $strAddPrivilegesOnDb = 'Aşağıdakı me\'lumat bazası üçün selahiyyet müeyyen et';
@@ -198,8 +194,8 @@ $strEnd = 'Son';
 $strEngineDisabled = '%s motoru bu serverde söndürülmüşdür.';
 $strEngines = 'Motorlar';
 $strEngineUnsupported = 'Bu MySQL server %s depolama motorunu desteklememektedir.';
-$strEnglishPrivileges = ' Qeyd: MySQL selahiyyet adları ingilis dilinde ifade edilmişdir ';
 $strEnglish = 'İngilis Dili';
+$strEnglishPrivileges = ' Qeyd: MySQL selahiyyet adları ingilis dilinde ifade edilmişdir ';
 $strError = 'Xeta';
 $strEstonian = 'Eston Dili';
 $strExcelEdition = 'Excel versiyası';
@@ -263,16 +259,15 @@ $strImportDocSQL = 'docSQL Fayllarını İmport Et';
 $strImportFiles = 'Faylları import et';
 $strIndexes = 'Indeksler';
 $strIndexHasBeenDropped = '%s indeksi leğv edildi';
+$strIndex = 'İndeks';
 $strIndexName = 'İndex adı&nbsp;:';
 $strIndexType = 'İndex tipi&nbsp;:';
-$strIndex = 'İndeks';
 $strInnodbStat = 'InnoDB Status';
 $strInsecureMySQL = 'Konfiqurasiya faylınızda MySQL başlanğıc deyerleri (parolsuz root istifadeçisi) mövcuddur ki, bu da tehlükesizlik nöqteyi nezerinden e\'tibarlı deyildir.';
 $strInsertAsNewRow = 'Yeni setir olaraq elave et';
 $strInsertedRowId = 'Elave edilen setir nömresi (id):';
 $strInsertedRows = 'Elave edilen setir sayı:';
 $strInsert = 'Elave et';
-$strInsertNewRow = 'Yeni setir elave et';
 $strInUse = 'istifadede';
 
 $strJumpToDB = '&quot;%s&quot; me\'lumat bazasına keç.';
@@ -341,8 +336,8 @@ $strNoDetailsForEngine = 'Bu depolama motoru haqqında etrafli status me\'lumat
 $strNoDropDatabases = '"DROP DATABASE" ifadeleri söndürülmüşdür (disabled).';
 $strNoExplain = 'SQL İzah Et-i Keç';
 $strNoFrames = 'phpMyAdmin <b>frame-destekli</b> görüntüleyicilerle (browser) daha yaxşı işleyir.';
-$strNoIndexPartsDefined = 'İndeks qisimleri te\'yin edilmedi!';
 $strNoIndex = 'İndeks te\'yin edilmedi!';
+$strNoIndexPartsDefined = 'İndeks qisimleri te\'yin edilmedi!';
 $strNoModification = 'Deyişiklik Yoxdur';
 $strNone = 'Heç biri';
 $strNoOptions = 'Bu formatın variantları yoxdur';
@@ -428,6 +423,7 @@ $strPrivDescUpdate = 'Allows changing data.';
 $strPrivDescUsage = 'Selahiyyet te\'yin edilmedi.';
 $strPrivilegesReloaded = 'The privileges were reloaded successfully.';
 $strPrivileges = 'Selahiyyetler';
+$strProcesses = 'Prosesler';
 $strProcesslist = 'Proses Siyahısı';
 $strPutColNames = 'Sahe adlarını birinci setre yerleşdir';
 
@@ -449,7 +445,6 @@ $strRelationNotWorking = 'Elaqelendirilmiş cedveller üçün nezerde tutulmuş
 $strRelations = 'Relations';
 $strRelationView = 'Relation view';
 $strReloadingThePrivileges = 'Reloading the privileges';
-$strReloadMySQL = 'Reload MySQL';
 $strRemoveSelectedUsers = 'Remove selected users';
 $strRenameTable = 'Cedveli yeniden adlandır';
 $strRenameTableOK = '%s cedveli %s olaraq yeniden adlandırılmışdır';
@@ -470,8 +465,8 @@ $strRowsModeFlippedHorizontal = 'üfüqi (tekrarlanan başlıqlar)';
 $strRowsModeHorizontal = 'üfüqi';
 $strRowsModeOptions = '%s rejimde, başlıqlar %s blokdan bir tekrar ederek';
 $strRowsModeVertical = 'şaquli';
-$strRowsStatistic = 'Sıra Statistikası';
 $strRows = 'Sıra sayı';
+$strRowsStatistic = 'Sıra Statistikası';
 $strRunning = '%s üzerinde işlemektedir';
 $strRunQuery = 'Emri İcra Et';
 $strRunSQLQuery = '%s me\'lumat bazasına SQL sorğusu(-ları) gönder';
@@ -500,7 +495,6 @@ $strServerChoice = 'Quraşdırılmış Serverler';
 $strServer = 'Server';
 $strServerStatus = 'Runtime Me\'lumatı';
 $strServerStatusUptime = 'Bu MySQL server %sdir işlemektedir. Server %s-de açılmışdır.';
-$strServerTabProcesslist = 'Prosesler';
 $strServerTabVariables = 'Deyişenler';
 $strServerTrafficNotes = '<b>Server Neqliyyatı</b>: Bu cedveller serverin açılışından beri elde edilen me\'lumat axışı miqdarını göstermektedir.';
 $strServerVars = 'Server Deyişenleri Ve Variantları';
@@ -542,7 +536,6 @@ $strStorageEngine = 'Depolama Motorları';
 $strStorageEngines = 'MySQL Depolama Motorları';
 $strStrucCSV = 'CSV verilenleri';
 $strStrucData = 'Quruluş ve me\'lumat';
-$strStrucDrop = '\'Cedveli leğv et\' elaveli';
 $strStrucExcelCSV = 'MS Excel verilenleri üçün CSV';
 $strStrucOnly = 'Sadece quruluş';
 $strStructPropose = 'Alternativ cedvel strukturu';
@@ -562,7 +555,6 @@ $strTableMaintenance = 'Cedvel temizliyi';
 $strTableOfContents = 'İçindekiler Cedveli';
 $strTables = '%s cedvel';
 $strTableStructure = 'Table structure for table';
-$strTableType = 'Cedvel tipi';
 $strTblPrivileges = 'Cedvelexas selahiyyetler';
 $strTextAreaLength = ' Uzun olduğuna göre,<br /> bu sahedeki me\'lumatlar deyişdirilmeye biler ';
 $strThisHost = 'Bu Host';
@@ -599,12 +591,12 @@ $strUseBackquotes = 'Cedvel ve sahe adlarını tek dırnaq arasına al';
 $strUseHostTable = 'Use Host Table';
 $strUserAlreadyExists = '%s istifadeçisi mövcuddur!';
 $strUserEmpty = 'İstifadeçi adı boş qaldı!';
+$strUser = 'İstifadeçi';
 $strUserName = 'İstifadeçi adı';
 $strUserNotFound = 'The selected user was not found in the privilege table.';
 $strUserOverview = 'User overview';
 $strUsersDeleted = 'The selected users have been deleted successfully.';
 $strUsersHavingAccessToDb = 'Users having access to &quot;%s&quot;';
-$strUser = 'İstifadeçi';
 $strUseTables = 'Use Tables';
 $strUseTextField = 'Use text field';
 
@@ -634,9 +626,11 @@ $strZeroRemovesTheLimit = 'Qeyd: Bu variantları 0 (sıfır)-a çevirmek hüdudu
 $strZip = '"zip"lenmiş';
 
 // To translate:
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
 $strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
 $strAddConstraints = 'Add constraints';  //to translate
 $strAddFields = 'Add %s field(s)';  //to translate
+$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
 $strAndThen = 'and then';  //to translate
 $strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
 
@@ -649,6 +643,9 @@ $strBinLogOriginalPosition = 'Original position';  //to translate
 $strBinLogPosition = 'Position';  //to translate
 $strBinLogServerId = 'Server ID';  //to translate
 $strBookmarkAllUsers = 'Let every user access this bookmark';  //to translate
+$strBookmarkCreated = 'Bookmark %s created';  //to translate
+$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
 $strBrowseForeignValues = 'Browse foreign values';  //to translate
 $strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
 $strBufferPool = 'Buffer Pool';  //to translate
@@ -660,6 +657,7 @@ $strBufferWriteWaits = 'Write waits';  //to translate
 $strBusyPages = 'Busy pages';  //to translate
 
 $strCalendar = 'Calendar';  //to translate
+$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
 $strCaseInsensitive = 'case-insensitive';  //to translate
 $strCaseSensitive = 'case-sensitive';  //to translate
 $strCharsetsAndCollations = 'Character Sets and Collations';  //to translate
@@ -668,11 +666,15 @@ $strCheckOverhead = 'Check tables with overhead';  //to translate
 $strCollation = 'Collation';  //to translate
 $strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
 $strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
 $strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
 $strConstraintsForTable = 'Constraints for table';  //to translate
 $strCopy = 'Copy';  //to translate
 $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
+$strCSV = 'CSV';  //to translate
+$strCSVImportOptions = 'CSV options';  //to translate
 $strCzech = 'Czech';  //to translate
 
 $strDanish = 'Danish';  //to translate
@@ -683,6 +685,7 @@ $strDBCopy = 'Copy database to';  //to translate
 $strDBRename = 'Rename database to';  //to translate
 $strDefragment = 'Defragment table';  //to translate
 $strDelayedInserts = 'Use delayed inserts';  //to translate
+$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
 $strDescription = 'Description';  //to translate
 $strDictionary = 'dictionary';  //to translate
 $strDirtyPages = 'Dirty pages';  //to translate
@@ -690,9 +693,18 @@ $strDisableForeignChecks = 'Disable foreign key checks';  //to translate
 
 $strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
 $strEngineAvailable = '%s bu MySQL serverde quruludur.';  //to translate
+$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
 $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strEsperanto = 'Esperanto';  //to translate
 $strExecuteBookmarked = 'Execute bookmarked query';  //to translate
 
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strFileToImport = 'File to import';  //to translate
+$strFlushQueryCache = 'Flush query cache';  //to translate
+$strFlushTables = 'Flush (close) all tables';  //to translate
 $strFreePages = 'Free pages';  //to translate
 
 $strGenerate = 'Generate';  //to translate
@@ -700,8 +712,14 @@ $strGeneratePassword = 'Generate Password';  //to translate
 $strGerman = 'German';  //to translate
 $strGreek = 'Greek';  //to translate
 
+$strHandler = 'Handler';  //to translate
+
 $strIcelandic = 'Icelandic';  //to translate
+$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strIgnoreInserts = 'Use ignore inserts';  //to translate
+$strImportFormat = 'Format of imported file';  //to translate
+$strImport = 'Import';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
 $strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
 $strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
@@ -716,22 +734,39 @@ $strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoD
 $strInnoDBPages = 'pages';  //to translate
 $strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';  //to translate
 $strInternalRelations = 'Internal relations';  //to translate
+$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
 $strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
+$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
 $strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
 $strInvalidFieldCount = 'Table must have at least one field.';  //to translate
+$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
 $strInvalidRowNumber = '%d is not valid row number.';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
 
 $strJapanese = 'Japanese';  //to translate
+$strJoins = 'Joins';  //to translate
 
+$strKeyCache = 'Key cache';  //to translate
 $strKorean = 'Korean';  //to translate
 
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatexContent = 'Content of table __TABLE__';//to translate
 $strLatexStructure = 'Structure of table __TABLE__';//to translate
 $strLatvian = 'Latvian';  //to translate
+$strLDI = 'CSV using LOAD DATA';  //to translate
+$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
+$strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLogServer = 'Server';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
+$strMaxConnects = 'max. concurrent connections';  //to translate
+$strMaximalQueryLength = 'Maximal length of created query';  //to translate
 $strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
 $strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
@@ -744,17 +779,25 @@ $strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISA
 $strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
 $strMyISAMRepairThreads = 'Repair threads';  //to translate
 $strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
 $strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
 
 $strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
 $strNoRowsSelected = 'No rows selected';  //to translate
 $strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strNumberOfFields = 'Number of fields';  //to translate
 
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 $strOperator = 'Operator';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPaperSize = 'Paper size';  //to translate
+$strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
 $strPhoneBook = 'phone book';  //to translate
 $strPolish = 'Polish';  //to translate
@@ -764,87 +807,31 @@ $strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
 $strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
 $strPrivDescCreateView = 'Allows creating new views.';  //to translate
 $strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
 $strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
 
+$strQueryCache = 'Query cache';  //to translate
 $strQueryWindowLock = 'Do not overwrite this query from outside the window';  //to translate
 
 $strReadRequests = 'Read requests';  //to translate
 $strRefresh = 'Refresh';  //to translate
 $strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
+$strReloadPrivileges = 'Reload privileges';  //to translate
 $strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
+$strReplication = 'Replication';  //to translate
 $strRomanian = 'Romanian';  //to translate
+$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
 $strRussian = 'Russian';  //to translate
 
 $strSecretRequired = 'The configuration file now needs a secret passphrase (blowfish_secret).';  //to translate
 $strSelectBinaryLog = 'Select binary log to view';  //to translate
 $strServerNotResponding = 'The server is not responding';  //to translate
-$strSimplifiedChinese = 'Simplified Chinese';  //to translate
-$strSlovak = 'Slovak';  //to translate
-$strSlovenian = 'Slovenian';  //to translate
-$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
-$strSortByKey = 'Sort by key';  //to translate
-$strSpanish = 'Spanish';  //to translate
-$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
-$strStrucNativeExcel = 'Native MS Excel data';  //to translate
-$strSwedish = 'Swedish';  //to translate
-$strSwitchToDatabase = 'Switch to copied database';  //to translate
-
-$strTableOptions = 'Table options';  //to translate
-$strTakeIt = 'take it';  //to translate
-$strThai = 'Thai';  //to translate
-$strTheme = 'Theme / Style';  //to translate
-$strToggleScratchboard = 'toggle scratchboard';  //to translate
-$strTraditionalSpanish = 'Traditional Spanish';  //to translate
-$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
-$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
-
-$strUnicode = 'Unicode';  //to translate
-$strUnknown = 'unknown';  //to translate
-$strUpgrade = 'You should upgrade to %s %s or later.';  //to translate
-$strUseTabKey = 'TAB düymesine basaraq bir sonrakı deyere, ve ya CTRL+Ox kombinasiyasını istifade ederek istediyiniz yöne keçe bilersiniz.';  //to translate
-$strUseThisValue = 'Use this value';  //to translate
-
-$strVersionInformation = 'Version information';  //to translate
-$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
-$strView = 'View';  //to translate
-
-$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';  //to translate
-$strWriteRequests = 'Write requests';  //to translate
-
-$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
-$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
-$strCSV = 'CSV';  //to translate
-$strImport = 'Import';  //to translate
-$strImportFormat = 'Format of imported file';  //to translate
-$strFileToImport = 'File to import';  //to translate
-$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
-$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
-$strPartialImport = 'Partial import';  //to translate
-$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
-$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
-$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
-$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
-$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
-$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
-$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
-$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
-$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
-$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
-$strFlushQueryCache = 'Flush query cache';  //to translate
-$strFlushTables = 'Flush (close) all tables';  //to translate
-$strHandler = 'Handler';  //to translate
-$strJoins = 'Joins';  //to translate
-$strKeyCache = 'Key cache';  //to translate
-$strMaxConnects = 'max. concurrent connections';  //to translate
-$strQueryCache = 'Query cache';  //to translate
-$strReplication = 'Replication';  //to translate
 $strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
+$strShowingBookmark = 'Showing bookmark';  //to translate
 $strShowOpenTables = 'Show open tables';  //to translate
 $strShowSlaveHosts = 'Show slave hosts';  //to translate
 $strShowSlaveStatus = 'Show slave status';  //to translate
-$strShowStatusReset = 'Reset';  //to translate
 $strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
 $strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
 $strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
@@ -896,13 +883,13 @@ $strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to t
 $strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
 $strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
 $strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
-$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
 $strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
+$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
 $strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
 $strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
 $strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
-$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
 $strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
@@ -918,10 +905,10 @@ $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key b
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
 $strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
 $strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
-$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
 $strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
 $strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
@@ -930,11 +917,12 @@ $strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been
 $strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
 $strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
 $strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
+$strShowStatusReset = 'Reset';  //to translate
 $strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
 $strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
 $strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
-$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
 $strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
+$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
 $strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
 $strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
 $strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
@@ -951,53 +939,84 @@ $strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache.
 $strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
 $strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
 $strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
+$strSimplifiedChinese = 'Simplified Chinese';  //to translate
+$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
+$strSlovak = 'Slovak';  //to translate
+$strSlovenian = 'Slovenian';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+$strSortByKey = 'Sort by key';  //to translate
 $strSorting = 'Sorting';  //to translate
-$strTempData = 'Temporary data';  //to translate
-$strThreads = 'Threads';  //to translate
-$strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDILocal = 'Use LOCAL keyword';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
-$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strSpanish = 'Spanish';  //to translate
+$strSQLCompatibility = 'SQL compatibility mode';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strStrucNativeExcel = 'Native MS Excel data';  //to translate
+$strSwedish = 'Swedish';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+
 $strTableAlreadyExists = 'Table %s already exists!';  //to translate
-$strTransactionCoordinator = 'Transaction coordinator';  //to translate
-$strNumberOfFields = 'Number of fields';  //to translate
-$strShowingBookmark = 'Showing bookmark';  //to translate
-$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
-$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
-$strMaximalQueryLength = 'Maximal length of created query';  //to translate
-$strBookmarkCreated = 'Bookmark %s created';  //to translate
-$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
-$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
-$strEsperanto = 'Esperanto';  //to translate
-$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
-$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
-$strFileNameTemplateDescriptionTable = 'table name';  //to translate
-$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
-$strFileNameTemplateDescriptionServer = 'server name';  //to translate
-$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
-$strProtocolVersion = 'Protocol version';  //to translate
-$strMysqlClientVersion = 'MySQL client version';  //to translate
-$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
-$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
-$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
-$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
-$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
-$strPDF = 'PDF';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
-$strPDFReportTitle = 'Report title';  //to translate
-$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
-$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
-$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
-$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strTableOptions = 'Table options';  //to translate
+$strTakeIt = 'take it';  //to translate
+$strTempData = 'Temporary data';  //to translate
+$strThai = 'Thai';  //to translate
 $strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
 $strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
 $strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
-$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
-$strBrowseDistinctValues = 'Browse distinct values';  //to translate
-$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strTheme = 'Theme / Style';  //to translate
+$strThreads = 'Threads';  //to translate
+$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
+$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
+$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
+$strToggleScratchboard = 'toggle scratchboard';  //to translate
+$strTraditionalSpanish = 'Traditional Spanish';  //to translate
+$strTransactionCoordinator = 'Transaction coordinator';  //to translate
+$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
+$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
+
+$strUnicode = 'Unicode';  //to translate
+$strUnknown = 'unknown';  //to translate
+$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
+$strUpgrade = 'You should upgrade to %s %s or later.';  //to translate
+$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strUseTabKey = 'TAB düymesine basaraq bir sonrakı deyere, ve ya CTRL+Ox kombinasiyasını istifade ederek istediyiniz yöne keçe bilersiniz.';  //to translate
+$strUseThisValue = 'Use this value';  //to translate
+
+$strVersionInformation = 'Version information';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
 $strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
+$strView = 'View';  //to translate
+
+$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+
+$strQueryResultsOperations = 'Query results operations';  //to translate
+$strAddClause = 'Add %s';  //to translate
+$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
+$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
+$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
+$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
+$strXMLOptions = 'XML options';  //to translate
+$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
+$strCreateUserDatabase = 'Database for user';  //to translate
+$strCreateUserDatabaseNone = 'None';  //to translate
+$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strOpenDocumentText = 'Open Document Text';  //to translate
+$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
+$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
+$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
+$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
+$strInvalidTableName = 'Invalid table name';  //to translate
+$strInvalidDatabase = 'Invalid database';  //to translate
+$strServers = 'Servers';  //to translate
+$strDelimiter = 'Delimiter';  //to translate
+$strFunctions = 'Functions';  //to translate
+$strProcedures = 'Procedures';  //to translate
+$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
+$strFontSize = 'Font size';  //to translate
+$strLanguage = 'Language';  //to translate
 ?>
