@@ -1,5 +1,5 @@
 <?php
-/* $Id: belarusian_cyrillic-windows-1251.inc.php,v 1.49.2.3 2006/03/23 17:42:10 lem9 Exp $ */
+/* $Id: belarusian_cyrillic-windows-1251.inc.php,v 1.74.2.1 2006/08/12 20:24:34 lem9 Exp $ */
 
 /**
  *     Translated by:
@@ -8,13 +8,12 @@
  */
 
 $charset = 'windows-1251';
+$allow_recoding = TRUE;
 $text_dir = 'ltr';
-$left_font_family = 'verdana, tahoma, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'verdana, tahoma, arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('', '', '', '', '', '', '');
+$byteUnits = array('', 'i', '̳', 'ó', 'ҳ', 'ϳ', 'ݳ');
 
 $day_of_week = array('', '', '', '', '', '', '');
 $month = array('', '', '', '', '', '', '˳', '', '', '', '˳', '');
@@ -30,15 +29,14 @@ $strAccessDeniedExplanation = 'phpMyAdmin     MySQL,   볢 .   ,     config.inc.
 $strAccessDenied = '  ';
 $strAction = '';
 $strAddAutoIncrement = '  AUTO_INCREMENT';
+$strAddClause = ' %s';
 $strAddConstraints = ' ';
 $strAddDeleteColumn = '/  ';
 $strAddDeleteRow = '/  ';
-$strAddDropDatabase = ' DROP DATABASE';
 $strAddedColumnComment = '   ';
 $strAddedColumnRelation = '   ';
 $strAddFields = '  ';
 $strAddHeaderComment = '     (\\n  )';
-$strAddIfNotExists = ' IF NOT EXISTS';
 $strAddIntoComments = '  ';
 $strAddNewField = '  ';
 $strAddPrivilegesOnDb = '    ';
@@ -113,6 +111,7 @@ $strBzError = 'phpMyAdmin     -    Bz2    PHP.      <code>$cfg[\'BZipDump\']</co
 $strBzip = '  bzip';
 
 $strCalendar = '';
+$strCanNotLoadExportPlugins = '   ,  ,   !';
 $strCanNotLoadImportPlugins = '   ,  ,  븢!';
 $strCannotLogin = '    MySQL';
 $strCantLoad = '   %s;<br /> ,   PHP';
@@ -175,6 +174,10 @@ $strCreateNewTable = '     %s';
 $strCreate = '';
 $strCreatePage = '  ';
 $strCreatePdfFeat = ' PDF-';
+$strCreateUserDatabase = '   ';
+$strCreateUserDatabaseName = '          ';
+$strCreateUserDatabaseNone = 'ͳ';
+$strCreateUserDatabaseWildcard = '        ( _%)';
 $strCreationDates = '// ';
 $strCriteria = '';
 $strCroatian = '';
@@ -227,6 +230,7 @@ $strDeleted = '  ';
 $strDeletedRows = ' :';
 $strDeleteNoUsersSelected = '    !';
 $strDeleting = ' %s';
+$strDelimiter = '';
 $strDelOld = '     ,    . ֳ     ?';
 $strDescending = '';
 $strDescription = '';
@@ -267,6 +271,7 @@ $strEnglish = '';
 $strEnglishPrivileges = ' :   MySQL  - ';
 $strError = '';
 $strErrorInZipFile = '  ZIP-:';
+$strErrorRenamingTable = '   %1$s  %2$s';
 $strEscapeWildcards = '  _  %     \    ';
 $strEsperanto = '';
 $strEstonian = '';
@@ -274,6 +279,7 @@ $strExcelEdition = ' Excel';
 $strExcelOptions = ' Excel';
 $strExecuteBookmarked = '   ';
 $strExplain = ' SQL';
+$strExportMustBeFile = '        !';
 $strExport = '';
 $strExtendedInserts = ' ';
 $strExtra = '';
@@ -300,11 +306,13 @@ $strFlushPrivilegesNote = ': phpMyAdmin        MySQL.       ,   ,     .      %s
 $strFlushQueryCache = '  ';
 $strFlushTable = '   ("FLUSH")';
 $strFlushTables = ' ()  ';
+$strFontSize = ' ';
 $strFormat = '';
 $strFormEmpty = '    !';
 $strFreePages = ' ';
 $strFullText = ' ';
 $strFunction = '';
+$strFunctions = '';
 
 $strGenBy = '';
 $strGeneralRelationFeat = '  ';
@@ -371,7 +379,6 @@ $strInsecureMySQL = '     ( root  ),     MySQL  .   MySQL            ,
 $strInsertAsNewRow = '   ';
 $strInsertedRowId = 'Id  :';
 $strInsertedRows = ' :';
-$strInsertNewRow = '  ';
 $strInsert = '';
 $strInternalNotNecessary = '*     ,      InnoDB.';
 $strInternalRelations = ' ';
@@ -382,12 +389,14 @@ $strInvalidColumnCount = '      .';
 $strInvalidCSVFieldCount = '  븢  CSV-   %d.';
 $strInvalidCSVFormat = '  CSV-   %d.';
 $strInvalidCSVParameter = '      CSV: %s';
+$strInvalidDatabase = '  ';
 $strInvalidFieldAddCount = '    .';
 $strInvalidFieldCount = '     .';
 $strInvalidLDIImport = '     !';
 $strInvalidRowNumber = '%d     .';
 $strInvalidServerHostname = '     %1$s.  ,  .';
 $strInvalidServerIndex = '  : "%s"';
+$strInvalidTableName = '  ';
 
 $strJapanese = '';
 $strJoins = '\'';
@@ -403,6 +412,7 @@ $strKorean = '';
 
 $strLandscape = '';
 $strLanguageFileNotFound = '  "%1$s"  .';
+$strLanguage = '';
 $strLanguageUnknown = ' : %1$s.';
 $strLatchedPages = 'Գ ';
 $strLatexCaption = ' ';
@@ -482,6 +492,7 @@ $strNext = '';
 $strNoActivity = '      %s .  ,  ';
 $strNoDatabases = '  ';
 $strNoDatabasesSelected = '   .';
+$strNoDataReceived = '    .      ,      ,   PHP. . FAQ 1.16.';
 $strNoDescription = ' ';
 $strNoDetailsForEngine = '        .';
 $strNoDropDatabases = ' "DROP DATABASE" .';
@@ -503,7 +514,6 @@ $strNoRowsSelected = 'ͳ   ';
 $strNoSpace = '      %s.';
 $strNoTablesFound = '     .';
 $strNoThemeSupport = '  ;  ,    /     %s.';
-$strNothingToImport = '    !';
 $strNotNumber = '  !';
 $strNotOK = ' OK';
 $strNotSet = ' <b>%s</b>       %s';
@@ -516,6 +526,10 @@ $strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ';
 $strNumTables = '';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheet = ' Open Document';
+$strOpenDocumentSpreadsheetOptions = '  Open Document';
+$strOpenDocumentTextOptions = '  Open Document';
+$strOpenDocumentText = ' Open Document';
 $strOpenNewWindow = '   phpMyAdmin';
 $strOperations = '';
 $strOperator = '';
@@ -539,6 +553,7 @@ $strPdfInvalidTblName = ' "%s"  !';
 $strPdfNoTables = ' ';
 $strPDFOptions = ' PDF';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(     )';
 $strPDFReportTitle = ' ';
 $strPerHour = ' ';
 $strPerMinute = ' ';
@@ -599,6 +614,8 @@ $strPrivDescUpdate = '  .';
 $strPrivDescUsage = ' .';
 $strPrivileges = '';
 $strPrivilegesReloaded = '   .';
+$strProcedures = '';
+$strProcesses = '';
 $strProcesslist = ' ';
 $strProtocolVersion = ' ';
 $strPutColNames = '  븢   ';
@@ -609,6 +626,7 @@ $strQBEIns = '';
 $strQueryCache = ' ';
 $strQueryFrame = ' ';
 $strQueryOnDb = 'SQL-   <b>%s</b>:';
+$strQueryResultsOperations = '   ';
 $strQuerySQLHistory = 'ó SQL';
 $strQueryStatistics = '<b> </b>:    %s     .';
 $strQueryTime = '  %01.4f ';
@@ -626,7 +644,7 @@ $strRelationsForTable = '  ';
 $strRelations = '';
 $strRelationView = ' ';
 $strReloadingThePrivileges = ' ';
-$strReloadMySQL = ' MySQL';
+$strReloadPrivileges = ' ';
 $strRemoveSelectedUsers = '  ';
 $strRenameDatabaseOK = '  %s    %s';
 $strRenameTable = '  ';
@@ -683,10 +701,10 @@ $strSent = '';
 $strServerChoice = ' ';
 $strServerNotResponding = '  ';
 $strServer = '';
+$strServers = '';
 $strServerStatus = ' ';
 $strServerStatusDelayedInserts = ' ';
 $strServerStatusUptime = '  MySQL  %s.    %s.';
-$strServerTabProcesslist = '';
 $strServerTabVariables = '';
 $strServerTrafficNotes = '<b> </b>:         MySQL    .';
 $strServerVars = '   ';
@@ -828,7 +846,7 @@ $strSorting = '';
 $strSpaceUsage = ' ';
 $strSpanish = 'ó';
 $strSplitWordsWithSpace = '   (" ").';
-$strSQLExportCompatibility = '  SQL';
+$strSQLCompatibility = '  SQL';
 $strSQLExportType = ' ';
 $strSQLImportOptions = ' SQL';
 $strSQLOptions = ' SQL';
@@ -850,9 +868,9 @@ $strStorageEngine = '  ';
 $strStorageEngines = '  ';
 $strStrucCSV = 'CSV';
 $strStrucData = '  ';
-$strStrucDrop = '  ';
 $strStrucExcelCSV = 'CSV   MS Excel';
 $strStrucNativeExcel = '  MS Excel';
+$strStrucNativeExcelOptions = '    Excel';
 $strStrucOnly = ' ';
 $strStructPropose = '  ';
 $strStructure = '';
@@ -875,7 +893,6 @@ $strTableOfContents = '';
 $strTableOptions = ' ';
 $strTables = '%s ()';
 $strTableStructure = ' ';
-$strTableType = ' ';
 $strTakeIt = '';
 $strTblPrivileges = ',   ';
 $strTempData = ' ';
@@ -903,7 +920,7 @@ $strTraditionalSpanish = ' ';
 $strTraffic = '';
 $strTransactionCoordinator = ' ';
 $strTransformation_application_octetstream__download = '      .                ,    .     ,      ';
-$strTransformation_application_octetstream__hex = '    .';
+$strTransformation_application_octetstream__hex = '    .        (-    8 ).';
 $strTransformation_image_jpeg__inline = '  ;        .   .';
 $strTransformation_image_jpeg__link = '     .';
 $strTransformation_image_png__inline = '  image/jpeg: ';
@@ -931,6 +948,7 @@ $strUpdateQuery = ' ';
 $strUpdComTab = '     column_comments ,  ,  ';
 $strUpgrade = '   %s   %s  .';
 $strUploadLimit = ', ,     .  ,   %s%s      .';
+$strUploadsNotAllowed = '      .';
 $strUsage = '';
 $strUseBackquotes = '      븢';
 $strUsedPhpExtensions = '  PHP';
@@ -972,6 +990,7 @@ $strWritingCommentNotPossible = '  ';
 $strWritingRelationNotPossible = '  ';
 $strWrongUser = ' /.   .';
 
+$strXMLOptions = ' XML';
 $strXML = 'XML';
 
 $strYes = '';
