@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_traditional-big5.inc.php,v 2.88.2.4 2006/03/23 17:42:11 lem9 Exp $ */
+/* $Id: chinese_traditional-big5.inc.php,v 2.114.2.1 2006/08/30 10:43:14 nijel Exp $ */
 
 /**
  * Last translation by: Siu Sun <siusun@best-view.net>
@@ -8,13 +8,13 @@
 
 $charset = 'big5';
 $text_dir = 'ltr';
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'helvetica, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
 
+$mysql_5_1_doc_lang = 'zh';
+
 $day_of_week = array('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
 $month = array('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec');
 // See http://www.php.net/manual/en/function.strftime.php to define the
@@ -23,48 +23,44 @@ $datefmt = '%B %d, %Y, %I:%M %p';
 
 $timespanfmt = '%s , %s p, %s  %s ';
 
-	
-
 $strAbortedClients = '';
 $strAbsolutePathToDocSqlDir = 'пJ docSQL ؿA|';
+$strAccessDenied = 'ڵs';
 $strAccessDeniedCreateConfig = 'iAإ߳]w. AiQΦ %1$sw˵{%2$s إ߳]w.';
 $strAccessDeniedExplanation = 'phpMyAdmin ճsu MySQL A, AڵFsu. z config.inc.php ˬdDW, nJW٤αKXνTOoǸƬOPtκ޲zHҴѪ MySQL AƬۦP';
-$strAccessDenied = 'ڵs';
 $strAction = '';
 $strAddAutoIncrement = "sW AUTO_INCREMENT ƭ";
 $strAddConstraints = '[J';
 $strAddDeleteColumn = 'sW/ ';
 $strAddDeleteRow = 'sW/ zC';
-$strAddDropDatabase = '[J \'Rƪ\' yk';
 $strAddedColumnComment = 'HU[JѤr';
 $strAddedColumnRelation = 'HU[Jp';
 $strAddFields = 'sW %s ';
 $strAddHeaderComment = 'D[JӤH (\\n }s)';
-$strAddIfNotExists = '[J IF NOT EXISTS';
 $strAddIntoComments = '[JѤr';
 $strAddNewField = 'W[s';
 $strAddPrivilegesOnDb = 'HUƮw[Jv';
 $strAddPrivilegesOnTbl = 'HUƪ[Jv';
 $strAddSearchConditions = 'W[˯ ("where" lyD)';
 $strAddToIndex = 'sW &nbsp;%s&nbsp; կ';
-$strAddUserMessage = 'zwsWF@ӷsϥΪ.';
 $strAddUser = 'sWϥΪ';
+$strAddUserMessage = 'zwsWF@ӷsϥΪ.';
 $strAdministration = 'tκ޲z';
 $strAffectedRows = 'vTC: ';
+$strAfter = 'b %s ';
 $strAfterInsertBack = '^';
 $strAfterInsertNewInsert = 'sW@O';
 $strAfterInsertNext = 'ss@C';
 $strAfterInsertSame = '^o';
-$strAfter = 'b %s ';
-$strAllTableSameWidth = 'HۦPeܩҦƪ?';
 $strAll = '';
+$strAllTableSameWidth = 'HۦPeܩҦƪ?';
 $strAlterOrderBy = 'ھ줺eƧǰO';
 $strAnalyzeTable = 'Rƪ';
 $strAnd = 'P';
 $strAndThen = 'M';
 $strAnIndex = 'ޤwgsW %s';
-$strAnyHost = 'D';
 $strAny = '';
+$strAnyHost = 'D';
 $strAnyUser = 'ϥΪ';
 $strApproximateCount = 'i౵. аѬ FAQ 3.11';
 $strAPrimaryKey = 'DwgsW %s';
@@ -81,8 +77,8 @@ $strBack = '^W@';
 $strBaltic = 'iùy';
 $strBeginCut = '}l Ũ';
 $strBeginRaw = '}l l';
-$strBinaryDoNotEdit = 'GiX - s';
 $strBinary = 'GiX';
+$strBinaryDoNotEdit = 'GiX - s';
 $strBinaryLog = 'GiO';
 $strBinLogEventType = 'ƥ覡';
 $strBinLogInfo = '';
@@ -101,13 +97,13 @@ $strBookmarkView = 'd';
 $strBrowse = 's';
 $strBrowseDistinctValues = 'sPƭ';
 $strBrowseForeignValues = 's~ӭ';
-$strBufferPoolActivity = 'wİϬʲv';
 $strBufferPool = 'wİ';
+$strBufferPoolActivity = 'wİϬʲv';
 $strBufferPoolUsage = 'wİϨϥΪŶ';
 $strBufferReadMisses = 'Ū|';
 $strBufferReadMissesInPercent = 'Ū| %';
-$strBufferWriteWaitsInPercent = 'gJ %';
 $strBufferWriteWaits = 'gJ';
+$strBufferWriteWaitsInPercent = 'gJ %';
 $strBulgarian = 'O[QȻy';
 $strBusyPages = 'c';
 $strBzError = 'phpMyAdmin LkY]o php  Bz2 Ҳտ~. jCnD phpMyAdmin ]wɳ]w <code>$cfg[\'BZipDump\']</code> <code>FALSE</code>. pGQϥ Bz2 Y\,Чs php ̷s. ԱаѬ php ~ %s .';
@@ -124,19 +120,19 @@ $strCardinality = 'էO';
 $strCaseInsensitive = 'jpg۲';
 $strCaseSensitive = 'jpg۲';
 $strCentralEuropean = 'ڻy';
+$strChange = 'ק';
+$strChangeCopyMode = 'إ߷sϥΪ̤ΨϥάۦPv,  ...';
 $strChangeCopyModeCopy = '... Od¨ϥΪ.';
 $strChangeCopyModeDeleteAndReload = ' ... R¨ϥΪ̤έsŪvƪ.';
 $strChangeCopyModeJustDelete = ' ... R¨ϥΪ.';
-$strChangeCopyMode = 'إ߷sϥΪ̤ΨϥάۦPv,  ...';
 $strChangeCopyModeRevoke = ' ... oҦ¨ϥΪ̦ĤvçR.';
 $strChangeCopyUser = 'nJT / ƻsϥΪ';
 $strChangeDisplay = 'ܤ';
-$strChange = 'ק';
 $strChangePassword = 'KX';
 $strCharset = 'rsX (Charset)';
 $strCharsetOfFile = 'rsXɮ:';
-$strCharsetsAndCollations = 'rsXήչ';
 $strCharsets = 'rsX';
+$strCharsetsAndCollations = 'rsXήչ';
 $strCheckAll = '';
 $strCheckOverhead = 'ˬdB~O (overhead)'; // nor sure yet.
 $strCheckPrivs = 'dv';
@@ -148,8 +144,8 @@ $strCollation = 'չ';
 $strColumnNames = 'W';
 $strColumnPrivileges = 'wv';
 $strCommand = 'O';
-$strCommentsForTable = 'COMMENTS FOR TABLE';  // keep in SQL statement
 $strComments = '';
+$strCommentsForTable = 'COMMENTS FOR TABLE';  // keep in SQL statement
 $strCompatibleHashing = 'MySQL&nbsp;4.0 ۮe';
 $strCompleteInserts = 'ϥΧsWO';
 $strCompression = 'Y';
@@ -162,18 +158,18 @@ $strConnections = 'su';
 $strConstraintsForDumped = 'ƥƪ';
 $strConstraintsForTable = 'ƪ';
 $strCookiesRequired = 'Cookies Ұʤ~nJ.';
-$strCopyDatabaseOK = 'Ʈw %s wƻs %s';
 $strCopy = 'ƻs';
+$strCopyDatabaseOK = 'Ʈw %s wƻs %s';
 $strCopyTable = 'ƻsƪG (榡 ƮwW<b>.</b>ƪW):';
 $strCopyTableOK = 'wgNƪ %s ƻs %s.';
 $strCopyTableSameNames = 'LkƻsۦPƪ!';
 $strCouldNotKill = 'phpMyAdmin Lk_O %s. ioOwg.';
+$strCreate = 'إ';
 $strCreateDatabaseBeforeCopying = 'ƻseإ߸Ʈw (CREATE DATABASE)';
 $strCreateIndex = 'sW &nbsp;%s&nbsp; կ';
 $strCreateIndexTopic = 'sW@կ';
 $strCreateNewDatabase = 'إ߷sƮw';
 $strCreateNewTable = 'إ߷sƪƮw %s';
-$strCreate = 'إ';
 $strCreatePage = 'إ߷s@';
 $strCreatePdfFeat = 'إ PDF';
 $strCreationDates = 'إ/s/ˬd ';
@@ -187,21 +183,21 @@ $strCzech = 'Jy';
 $strCzechSlovak = 'Jy';
 
 $strDanish = 'y';
+$strData = '';
+$strDatabase = 'Ʈw';
 $strDatabaseEmpty = 'ƮwW٨åJ!!';
 $strDatabaseExportOptions = 'ƮwXﶵ';
 $strDatabaseHasBeenDropped = 'Ʈw %s wQR';
 $strDatabaseNoTable = 'oƮwSƪ!';
+$strDatabases = 'Ʈw';
 $strDatabasesDropped = '%s ӸƮww\R.';
+$strDatabasesStats = 'Ʈwέp';
 $strDatabasesStatsDisable = 'έpƾ';
 $strDatabasesStatsEnable = 'Ұʲέpƾ';
 $strDatabasesStatsHeavyTraffic = ': ҰʸƮwέpƾڥi|ͤjq Web A MySQL yq.';
-$strDatabasesStats = 'Ʈwέp';
-$strDatabases = 'Ʈw';
-$strDatabase = 'Ʈw';
 $strDataDict = 'ƾڦr';
 $strDataOnly = 'u';
 $strDataPages = ']tƭ';
-$strData = '';
 $strDBComment = 'ƮwѤr: ';
 $strDBCopy = 'ƻsƮw';
 $strDBGContext = ' (Context)';
@@ -221,12 +217,12 @@ $strDefaultEngine = 'o MySQL Aw]xsO %s ';
 $strDefaultValueHelp = 'w]: ХuJӹw], Lݥ[Wϱ׽uΤ޸';
 $strDefragment = 'zƪ';
 $strDelayedInserts = 'ϥΩ𦡷sW';
-$strDeleteAndFlushDescr = 'oO@ӳ̲M䪺k,sŪvݤ@qɶ.';
+$strDelete = 'R';
 $strDeleteAndFlush = 'RϥΪ̤έsŪv.';
+$strDeleteAndFlushDescr = 'oO@ӳ̲M䪺k,sŪvݤ@qɶ.';
 $strDeleted = 'OwQR';
 $strDeletedRows = 'wR:';
 $strDeleteNoUsersSelected = 'åܻݭnRϥΪ!';
-$strDelete = 'R';
 $strDeleting = 'R %s';
 $strDelOld = 'ѦҨƪwsb. zƱRoǰѦҶ?';
 $strDescending = '';
@@ -241,8 +237,8 @@ $strDisplayPDF = ' PDF n';
 $strDoAQuery = 'HdҬd (UΦr : "%")';
 $strDocu = '';
 $strDoYouReally = 'zTwn ';
-$strDropDatabaseStrongWarning = 'zN|RӸƮw!';
 $strDrop = 'R';
+$strDropDatabaseStrongWarning = 'zN|RӸƮw!';
 $strDropUsersDb = 'RPϥΪ̬ۦPW٤Ʈw.';
 $strDumpingData = 'CXHUƮwƾڡG';
 $strDumpSaved = 'ƥwxɮ %s.';
@@ -264,10 +260,10 @@ $strEngineAvailable = '%s w䴩o MySQL A.';
 $strEngineDisabled = '%s vo MySQL A.';
 $strEngines = ''; 
 $strEngineUnsupported = 'o MySQL ä %s xs.';
-$strEnglishPrivileges = '`N: MySQL vWٷ|H^y';
 $strEnglish = '^y';
-$strErrorInZipFile = 'ZIP ɮ׿~:';
+$strEnglishPrivileges = '`N: MySQL vWٷ|H^y';
 $strError = '~';
+$strErrorInZipFile = 'ZIP ɮ׿~:';
 $strEscapeWildcards = 'UβŸ _  % Ta[J \ ';
 $strEsperanto = '@ɻy';
 $strEstonian = 'RFȻy';
@@ -313,9 +309,9 @@ $strGeneratePassword = 'ͱKX';
 $strGenTime = 'إߤ';
 $strGeorgian = '|NȻy';
 $strGerman = 'wy';
+$strGlobal = '';
 $strGlobalPrivileges = 'v';
 $strGlobalValue = '';
-$strGlobal = '';
 $strGo = '';
 $strGrantOption = 'v';
 $strGreek = 'þy';
@@ -344,11 +340,11 @@ $strIgnore = '';
 $strIgnoreDuplicates = 'LЦC';
 $strIgnoreInserts = 'ϥΩ[J (insert)'; 
 $strIgnoringFile = 'ɮ %s';
+$strImport = 'J';
 $strImportDocSQL = 'Ū docSQL ɮ';
 $strImportFiles = 'Jɮ';
 $strImportFormat = 'Jɮ׮榡';
 $strImportSuccessfullyFinished = 'J\, @ %d yykw.';
-$strImport = 'J';
 $strIndex = ' INDEX';
 $strIndexes = '';
 $strIndexHasBeenDropped = ' %s wQR';
@@ -358,21 +354,20 @@ $strIndexWarningMultiple = 'hL@ %s wإߨ `%s` ';
 $strIndexWarningPrimary = 'D PRIMARY   INDEX Pɶ]w `%s` ';
 $strIndexWarningTable = 'ƪ `%s` ްD';
 $strIndexWarningUnique = 'ߤ@ UNIQUE   INDEX Pɶ]w `%s` ';
-$strInnoDBAutoextendIncrementDesc = 'ƪeq񺡮, ۰ʼWjeqjp.';
 $strInnoDBAutoextendIncrement = '۰ʦjp';
-$strInnoDBBufferPoolSizeDesc = 'InnoDB ƪΩ֨ƤίޮɨϥΪOwĤjp.';
+$strInnoDBAutoextendIncrementDesc = 'ƪeq񺡮, ۰ʼWjeqjp.';
 $strInnoDBBufferPoolSize = 'wİϤjp';
+$strInnoDBBufferPoolSizeDesc = 'InnoDB ƪΩ֨ƤίޮɨϥΪOwĤjp.';
 $strInnoDBDataFilePath = 'ɮ';
-$strInnoDBDataHomeDirDesc = 'Ҧ InnoDB ɮתDƥؿm.';
 $strInnoDBDataHomeDir = 'ƥDؿ';
+$strInnoDBDataHomeDirDesc = 'Ҧ InnoDB ɮתDƥؿm.';
 $strInnoDBPages = '';
 $strInnodbStat = 'InnoDB A';
 $strInsecureMySQL = ']wɤ]w (rootnJΨSKX) Pw] MySQL vfۦPC MySQL Abow]]wB檺ܷ|ܮeQJIAz靈]whw|}C';
+$strInsert = 'sW';
 $strInsertAsNewRow = 'xssO';
 $strInsertedRowId = 'sWƦC id:';
 $strInsertedRows = 'sWC:';
-$strInsertNewRow = 'sW@O';
-$strInsert = 'sW';
 $strInternalNotNecessary = '* pb InnoDB wsbɬOLݭn.';
 $strInternalRelations = 'p';
 $strInUse = 'ϥΤ';
@@ -392,8 +387,8 @@ $strInvalidServerIndex = 'A޿~: "%s"';
 $strJapanese = 'y';
 $strJoins = 'X';
 $strJumpToDB = 'Ʈw &quot;%s&quot;.';
-$strJustDeleteDescr = ' &quot;R&quot; ϥΪ̤MnJƮwܭsJƮw.';
 $strJustDelete = 'uqvƮwRϥΪ.';
+$strJustDeleteDescr = ' &quot;R&quot; ϥΪ̤MnJƮwܭsJƮw.';
 
 $strKeepPass = 'ФnKX';
 $strKeyCache = '֨';
@@ -405,13 +400,13 @@ $strLandscape = 'V';
 $strLanguageFileNotFound = '䤣yɮ "%1$s".';
 $strLanguageUnknown = 'Wy: %1$s.';
 $strLatchedPages = 'W';
+$strLaTeX = 'LaTeX';  // use eng
 $strLatexCaption = 'ƪD';
 $strLatexContent = 'ƪ __TABLE__ e';
 $strLatexContinued = '(s)';
 $strLatexContinuedCaption = 'sƪD';
 $strLatexIncludeCaption = ']AƪD';
 $strLatexLabel = 'аOW';
-$strLaTeX = 'LaTeX';  // use eng
 $strLaTeXOptions = 'LaTeX ﶵ';
 $strLatexStructure = 'ƪ __TABLE__ c';
 $strLatvian = 'ԲȻy';
@@ -426,8 +421,8 @@ $strLinksTo = 's';
 $strLithuanian = '߳{y';
 $strLocalhost = 'a';
 $strLocationTextfile = 'rɮתm';
-$strLoginInformation = 'nJT';
 $strLogin = 'nJ';
+$strLoginInformation = 'nJT';
 $strLogout = 'nXt';
 $strLogPassword = 'KX:';
 $strLogServer = 'A';
@@ -448,8 +443,8 @@ $strMIME_transformation = 'sഫ覡';
 $strMIME_transformation_note = 'iϥΤഫ覡ﶵ MINE ഫﶵ, Ьd %sഫ覡%s';
 $strMIME_transformation_options = 'ഫ覡ﶵ';
 $strMIME_transformation_options_note = 'ХΥHU榡Jഫﶵ: \'a\',\'b\',\'c\'...<br />pzݭnJϱ׽u ("\") γ޸ ("\'") ЦA[Wϱ׽u (Ҧp \'\\\\xyz\' or \'a\\\'b\').';
-$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  // keep in SQL statement
 $strMIME_without = 'MIME HܬOSjഫ\';
+$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  // keep in SQL statement
 $strModifications = 'קwxs';
 $strModify = 'ק';
 $strModifyIndexTopic = 'ק';
@@ -457,16 +452,16 @@ $strMoveTable = 'ʸƪG(榡 ƮwW<b>.</b>ƪW)';
 $strMoveTableOK = 'ƪ %s wgʨ %s.';
 $strMoveTableSameNames = 'LkʨۦPƪ!';
 $strMultilingual = 'hy';
-$strMyISAMDataPointerSizeDesc = 'w]ƫФjpɷH CREATE TABLE إ MyISAM ƪ, ӨõL]w̤jC (MAX_ROWS) , N|H짹լ]wjp';
 $strMyISAMDataPointerSize = 'ƫФjp';
+$strMyISAMDataPointerSizeDesc = 'w]ƫФjpɷH CREATE TABLE إ MyISAM ƪ, ӨõL]w̤jC (MAX_ROWS) , N|H짹լ]wjp';
 $strMyISAMMaxExtraSortFileSize = '{ɮ׫إ߯ޮɳ̤jeq';
 $strMyISAMMaxExtraSortFileSizeDesc = 'p{ɮץΧ@ֳt MyISAM ޮɤjoӳ]weq, ĳϥW֨覡.';
 $strMyISAMMaxSortFileSize = '{ɱƧɮ׳̤jeq';
 $strMyISAMMaxSortFileSizeDesc = 'MySQL Ω󭫫 MyISAM  (REPAIR TABLE, ALTER TABLE,  LOAD DATA INFILE) ɪ{ɮפjp.';
-$strMyISAMRecoverOptionsDesc = 'oӼҦN|۰ʭ״_la MyISAM ƪ, pPAҰʳ]w[J --myisam-recover ﶵ.';
 $strMyISAMRecoverOptions = '۰ʭ״_Ҧ';
-$strMyISAMRepairThreadsDesc = 'pƭȤj 1 , MyISAM ƪ״_ɤޱN|HPBإ.';
+$strMyISAMRecoverOptionsDesc = 'oӼҦN|۰ʭ״_la MyISAM ƪ, pPAҰʳ]w[J --myisam-recover ﶵ.';
 $strMyISAMRepairThreads = '״_u@';
+$strMyISAMRepairThreadsDesc = 'pƭȤj 1 , MyISAM ƪ״_ɤޱN|HPBإ.';
 $strMyISAMSortBufferSize = 'ƧǽwĤjp';
 $strMyISAMSortBufferSizeDesc = 'oӽwĤjpOtb״_ƪO (REPAIR TABLE) B CREATE INDEX  ALTER TABLE O, ΩƧ MyISAM ޤ';
 $strMySQLCharset = 'MySQL rsX';
@@ -481,16 +476,16 @@ $strName = 'W';
 $strNext = 'U@';
 $strNo = ' _ ';
 $strNoActivity = 'ѩwmFF %s , ЭsnJ';
-$strNoDatabasesSelected = 'SƮw.';
 $strNoDatabases = 'SƮw';
+$strNoDatabasesSelected = 'SƮw.';
 $strNoDescription = 'S';
 $strNoDetailsForEngine = 'oxsõLԲӪA.';
 $strNoDropDatabases = '"DROP DATABASE" Owg.';
 $strNoExplain = 'L SQL';
 $strNoFilesFoundInZip = ' ZIP ɮפ䤣ɮ!';
 $strNoFrames = 'phpMyAdmin AXϥΦb䴩<b></b>s.';
-$strNoIndexPartsDefined = '޸٥wq!';
 $strNoIndex = 'Swwq!';
+$strNoIndexPartsDefined = '޸٥wq!';
 $strNoModification = 'Sܧ';
 $strNone = 'A';
 $strNoOptions = 'oخ榡õLﶵ';
@@ -503,7 +498,6 @@ $strNoRowsSelected = 'õLƦCw';
 $strNoSpace = 'Ŷxsɮ %s.';
 $strNoTablesFound = 'ƮwSƪ';
 $strNoThemeSupport = '䴩ڦ\, Ьdݳ]wפxsڦɮתƧ %s.';
-$strNothingToImport = 'Aåg, LkJ!';
 $strNotNumber = 'oO@ӼƦr!';
 $strNotOK = 'Tw';
 $strNotSet = '<b>%s</b> ƪ䤣٥b %s ]w';
@@ -529,24 +523,24 @@ $strPagesToBeFlushed = 'js';
 $strPaperSize = 'ȱijp';
 $strPartialImport = 'J';
 $strPartialText = 'ܳr';
+$strPassword = 'KX';
 $strPasswordChanged = '%s KXw\.';
 $strPasswordEmpty = 'пJKX!';
 $strPasswordHashing = 'KX';
-$strPassword = 'KX';
 $strPasswordNotSame = 'ĤGJKXP!';
+$strPDF = 'PDF';  // USE ENG
 $strPdfDbSchema = '"%s" Ʈwn -  %s ';
 $strPdfInvalidTblName = 'ƪ "%s" sb!';
 $strPdfNoTables = 'Sƪ';
 $strPDFOptions = 'PDF ﶵ';
-$strPDF = 'PDF';  // USE ENG
 $strPDFReportTitle = 'iD';
 $strPerHour = 'Cp';
 $strPerMinute = 'C';
 $strPerSecond = 'C';
 $strPersian = 'iy';
 $strPhoneBook = 'qï';
-$strPHP40203 = 'zϥ PHP  4.2.3, o@r`rY~(mbstring). аѾ\ PHP γis 19404. phpMyAdmin äĳϥγoӪ PHP .';
 $strPhp = 'إ PHP {X';
+$strPHP40203 = 'zϥ PHP  4.2.3, o@r`rY~(mbstring). аѾ\ PHP γis 19404. phpMyAdmin äĳϥγoӪ PHP .';
 $strPHPVersion = 'PHP ';
 $strPmaDocumentation = 'phpMyAdmin ';
 $strPmaUriError = ' b]wɤ]w <tt>$cfg[\'PmaAbsoluteUri\']</tt> !';
@@ -559,8 +553,8 @@ $strPrimaryKeyHasBeenDropped = 'DwQR';
 $strPrimaryKeyName = 'D䪺W٥٬ PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b></b>OD䪺W٥HάO<b>ߤ@</b>@եD!)';
 $strPrint = 'CL';
-$strPrintViewFull = 'CL˵ (ܧr)';
 $strPrintView = 'CL˵';
+$strPrintViewFull = 'CL˵ (ܧr)';
 $strPrivDescAllPrivileges = ']AҦvFv (GRNANT).';
 $strPrivDescAlter = 'e\ק{ƪc.';
 $strPrivDescAlterRoutine = 'e\קΧRxs{.';
@@ -573,8 +567,8 @@ $strPrivDescCreateView = 'e\إ߷s˵.';
 $strPrivDescDelete = 'e\RO.';
 $strPrivDescDropDb = 'e\RƮwθƪ.';
 $strPrivDescDropTbl = 'e\Rƪ.';
-$strPrivDescExecute5 = 'e\xs{.';
 $strPrivDescExecute = 'e\ wxs{.  MySQL L.';
+$strPrivDescExecute5 = 'e\xs{.';
 $strPrivDescFile = 'e\JοXƾڨɮ.';
 $strPrivDescGrant = 'e\sWϥΪ̤vӵLݭsŪvƪ.';
 $strPrivDescIndex = 'e\إߤΧR.';
@@ -604,9 +598,9 @@ $strProcesslist = 'tΰM';
 $strProtocolVersion = 'qTw';
 $strPutColNames = 'NW٩b';
 
+$strQBE = '̽dҬd (QBE)';
 $strQBEDel = '';
 $strQBEIns = 'sW';
-$strQBE = '̽dҬd (QBE)';
 $strQueryCache = 'dߧ֨';
 $strQueryFrame = 'dߵ';
 $strQueryOnDb = 'bƮw <b>%s</b>  SQL yk:';
@@ -628,8 +622,7 @@ $strRelations = 'p';
 $strRelationsForTable = 'RELATIONS FOR TABLE';  // keep in SQL statement
 $strRelationView = 'p˵';
 $strReloadingThePrivileges = 'sŪv';
-$strReloadMySQL = 'sJ MySQL';
-$strReloadPrivileges = 'sŪv';
+$strReloadPrivileges = 'sŪv';  //to translate
 $strRemoveSelectedUsers = 'wܨϥΪ';
 $strRenameDatabaseOK = 'Ʈw %s wW٬ %s';
 $strRenameTable = 'NƪW';
@@ -642,11 +635,12 @@ $strReset = 'm';
 $strResourceLimits = '귽';
 $strReType = 'T{KX';
 $strRevoke = '';
-$strRevokeAndDeleteDescr = 'ϥΪ̤M USAGE vvƪsŪ.';
 $strRevokeAndDelete = 'oϥΪ̩ҦĤvçR.';
+$strRevokeAndDeleteDescr = 'ϥΪ̤M USAGE vvƪsŪ.';
 $strRevokeMessage = 'zwoϥΪ̪v: %s';
 $strRomanian = 'ùȻy';
 $strRowLength = 'ƦC';
+$strRows = 'ƦCC';
 $strRowsFrom = 'OA}lC:';
 $strRowSize = 'ƦCjp';
 $strRowsModeFlippedHorizontal = ' (D)';
@@ -654,19 +648,18 @@ $strRowsModeHorizontal = '';
 $strRowsModeOptions = 'ܬ %s 覡  Cj %s W';
 $strRowsModeVertical = '';
 $strRowsStatistic = 'ƦCέpƭ';
-$strRows = 'ƦCC';
 $strRunning = 'b %s ';
 $strRunQuery = 'yk';
-$strRunSQLQueryOnServer = 'A %s  SQL yk';
 $strRunSQLQuery = 'bƮw %s HUO';
+$strRunSQLQueryOnServer = 'A %s  SQL yk';
 $strRussian = 'Xy';
 
 $strSave = 'xs';
 $strSaveOnServer = 'xsA %s ؿ';
 $strScaleFactorSmall = 'ҭƤӲ, LkNϪb@';
+$strSearch = 'j';
 $strSearchFormTitle = 'jƮw';
 $strSearchInTables = 'HUƪ:';
-$strSearch = 'j';
 $strSearchNeedle = 'M䤧rμƭ (UΦr: "%"):';
 $strSearchOption1 = '@դr';
 $strSearchOption2 = 'Ҧr';
@@ -683,13 +676,12 @@ $strSelectNumRows = 'dߤ';
 $strSelectTables = 'ܸƪ';
 $strSend = 'Uxs';
 $strSent = 'eX';
+$strServer = 'A';
 $strServerChoice = 'ܦA';
 $strServerNotResponding = 'AõL^';
-$strServer = 'A';
 $strServerStatus = 'BT';
 $strServerStatusDelayedInserts = '𴡤J';
 $strServerStatusUptime = 'o MySQL AwҰʤF %s. A %s Ұ.';
-$strServerTabProcesslist = 'Bz';
 $strServerTabVariables = 'T';
 $strServerTrafficNotes = '<b>Ayq</b>: oǪܤF MySQL A۱ҰʥHӪyqέpC';
 $strServerVars = 'ATγ]w';
@@ -725,8 +717,8 @@ $strSorting = 'Ƨ';
 $strSpaceUsage = 'wϥΪŶ';
 $strSpanish = 'Zy';
 $strSplitWordsWithSpace = 'CդrHŮ (" ") j.';
+$strSQL = 'SQL'; // should express in english
 $strSQLCompatibility = 'SQL ݮeҦ';
-$strSQLExportCompatibility = 'SQL Xݮe';
 $strSQLExportType = 'X覡';
 $strSQLImportOptions = 'SQL ﶵ';
 $strSQLOptions = 'SQL ﶵ';
@@ -734,7 +726,6 @@ $strSQLParserBugMessage = 'oiOzF SQL R{@ǵ{~AвӤ߬dݱzykAˬd@U޸OTΨS|ALiX]iӦ
 $strSQLParserUserError = 'iOz SQL ykX{~Ap MySQL AoX~HAoiUzhXDҦbC';
 $strSQLQuery = 'SQL yk';
 $strSQLResult = 'SQL dߵG';
-$strSQL = 'SQL'; // should express in english
 $strSQPBugInvalidIdentifer = 'LĪѧOX (Invalid Identifer)';
 $strSQPBugUnclosedQuote = '޸ (Unclosed quote)';
 $strSQPBugUnknownPunctuation = 'IŸ (Unknown Punctuation String)';
@@ -748,7 +739,6 @@ $strStorageEngine = 'xs';
 $strStorageEngines = 'xs';
 $strStrucCSV = 'CSV ';
 $strStrucData = 'cP';
-$strStrucDrop = '[J \'Rƪ\' yk';
 $strStrucExcelCSV = 'MS Excel  CSV 榡';
 $strStrucNativeExcel = 'l MS Excel ';
 $strStrucOnly = 'uc';
@@ -761,6 +751,7 @@ $strSwedish = 'y';
 $strSwitchToDatabase = 'ಾƻsƮw';
 $strSwitchToTable = 'wƻsƪ';
 
+$strTable = 'ƪ';
 $strTableAlreadyExists = 'ƪ %s wsb!';
 $strTableComments = 'ƪѤr';
 $strTableEmpty = 'пJƪW!';
@@ -772,19 +763,17 @@ $strTableOfContents = 'ؿ';
 $strTableOptions = 'ƪﶵ';
 $strTables = '%s ƪ';
 $strTableStructure = 'ƪ榡G';
-$strTableType = 'ƪ';
-$strTable = 'ƪ';
 $strTakeIt = '';
 $strTblPrivileges = 'wƪv';
 $strTempData = 'Ȧs';
 $strTextAreaLength = ' ѩ׭<br /> 줣s ';
 $strThai = 'y';
+$strTheme = 'ڦ';
 $strThemeDefaultNotFound = '䤣w]GDD %s !';
 $strThemeNoPreviewAvailable = 'õLw.';
 $strThemeNotFound = '䤣GDD %s !';
 $strThemeNoValidImgPath = '䤣GDD %s ]wϹ|!';
 $strThemePathNotFound = '䤣GDD %s ]w|!';
-$strTheme = 'ڦ';
 $strThisHost = 'wD';
 $strThisNotDirectory = 'oäO@ӥؿ';
 $strThreads = 'u{';
@@ -829,6 +818,7 @@ $strUsage = 'ϥ';
 $strUseBackquotes = 'bƪϥΤ޸';
 $strUsedPhpExtensions = 'vϥ PHP XR';
 $strUseHostTable = 'ϥΥDƪ';
+$strUser = 'ϥΪ';
 $strUserAlreadyExists = 'ϥΪ %s vsb!';
 $strUserEmpty = 'пJϥΪ̦W!';
 $strUserName = 'ϥΪ̦W';
@@ -836,7 +826,6 @@ $strUserNotFound = 'ܪϥΪ̦bvƪ䤣.';
 $strUserOverview = 'ϥΪ̤@';
 $strUsersDeleted = 'ܪϥΪ̤w\R.';
 $strUsersHavingAccessToDb = 'iŪ &quot;%s&quot; ϥΪ';
-$strUser = 'ϥΪ';
 $strUseTabKey = ' TAB U@Ӽƭ,  CTRL+V @HN';
 $strUseTables = 'ϥθƪ';
 $strUseTextField = 'rJ';
@@ -854,8 +843,8 @@ $strViewDumpDB = '˵Ʈwƥn (dump schema)';
 $strViewHasBeenDropped = '˵ %s vQR.';
 $strViewMaxExactCount = 'oˬdwWL %s C, ԱаѬݦ%s%s.';
 
-$strWebServerUploadDirectoryError = ']wWؿ~Aϥ';
 $strWebServerUploadDirectory = 'Web AWؿ';
+$strWebServerUploadDirectoryError = ']wWؿ~Aϥ';
 $strWelcome = 'wϥ %s';
 $strWestEuropean = 'ڻy';
 $strWildcard = 'UΦr';
@@ -867,17 +856,16 @@ $strWritingRelationNotPossible = 'Lkxsp';
 $strWrongUser = '~ϥΪ̦W٩αKXAڵs';
 
 $strXML = 'XML'; //USE ENG
-
+	
 $strYes = ' O ';
 
 $strZeroRemovesTheLimit = ': ]woǿﶵ 0 (s) iѰ.';
 $strZip = '"zipped"';
 
+
 // To translate:
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
-
 $strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
-
 $strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
 $strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
 $strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
@@ -894,8 +882,8 @@ $strShowStatusHandler_read_firstDescr = 'The number of times the first entry was
 $strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
 $strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
 $strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
-$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
 $strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
+$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
 $strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
 $strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
 $strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
@@ -929,14 +917,14 @@ $strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to t
 $strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
 $strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
 $strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
-$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
 $strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
+$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
 $strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
 $strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
 $strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
 $strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
-$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
 $strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
 $strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
@@ -951,10 +939,10 @@ $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key b
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
 $strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
-$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
 $strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
+$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
 $strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
 $strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
@@ -984,11 +972,34 @@ $strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache.
 $strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
 $strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
 $strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
-
 $strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
 $strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
 $strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
-
 $strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
 
+$strAddClause = 'Add %s';  //to translate
+$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
+$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
+$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
+$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
+$strXMLOptions = 'XML options';  //to translate
+$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
+$strCreateUserDatabase = 'Database for user';  //to translate
+$strCreateUserDatabaseNone = 'None';  //to translate
+$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strOpenDocumentText = 'Open Document Text';  //to translate
+$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
+$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
+$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
+$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
+$strInvalidTableName = 'Invalid table name';  //to translate
+$strInvalidDatabase = 'Invalid database';  //to translate
+$strServers = 'Servers';  //to translate
+$strDelimiter = 'Delimiter';  //to translate
+$strFunctions = 'Functions';  //to translate
+$strProcedures = 'Procedures';  //to translate
+$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
+$strFontSize = 'Font size';  //to translate
+$strLanguage = 'Language';  //to translate
 ?>
