@@ -1,10 +1,8 @@
 <?php
-/* $Id: indonesian-iso-8859-1.inc.php,v 2.103 2005/10/30 10:03:49 nijel Exp $ */
+/* $Id: indonesian-iso-8859-1.inc.php,v 2.150 2006/08/09 12:55:37 lem9 Exp $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = '.';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
@@ -26,12 +24,10 @@ $strAddAutoIncrement = 'Menambahkan nilai AUTO_INCREMENT';
 $strAddConstraints = 'Menambahkan pembatas';
 $strAddDeleteColumn = 'Menambahkan/Hapus kolom';
 $strAddDeleteRow = 'Menambahkan/Hapus baris';
-$strAddDropDatabase = 'Menambahkan DROP DATABASE';
 $strAddedColumnComment = 'Komentar untuk kolum telah ditambahkan';
 $strAddedColumnRelation = 'Relasi untuk kolum telah ditambahkan';
 $strAddFields = 'Menambahkan %s field(s)';
 $strAddHeaderComment = 'Menambahkan komentar individual pada Header (\\n membelahkan garis)';
-$strAddIfNotExists = 'Berikut IF \'NOT EXISTS\'';
 $strAddIntoComments = 'Penambahkan pada komentar:';
 $strAddNewField = 'Menambahkan field baru';
 $strAddPrivilegesOnDb = 'Menambahkan hak (privileges) pada database berikut';
@@ -225,7 +221,6 @@ $strDocu = 'Dokumentasi';
 $strDoYouReally = 'Apakah anda ingin ';
 $strDropDatabaseStrongWarning = 'Anda akan MENGHAPUS SELURUH database!';
 $strDrop = 'Hapus';
-$strDropSelectedDatabases = 'Hapus database pilihan';
 $strDropUsersDb = 'Hapus database yang memiliki nama yang sama dengan pengguna.';
 $strDumpingData = 'Dumping data untuk tabel';
 $strDumpSaved = 'Dump (Skema) disimpan pada file %s.';
@@ -270,7 +265,6 @@ $strFields = 'Field';
 $strFieldsTerminatedBy = 'Fields diputus oleh';
 $strFileAlreadyExists = 'File %s sudah ada pada server. Gantikan nama file atau periksa pilihan Overwrite.';
 $strFileCouldNotBeRead = 'Gagal membaca File';
-$strFileNameTemplateHelp = 'Gunakan__DB__sebagai nama Database,__TABLE__sebagai nama tabel dan %sany strftime%s sebagai spesifikasi waktu. Ekstensi akan ditambahkan secara otomatis. Teks lainnya akan dipertahankan.';
 $strFileNameTemplate = 'Konvensi nama file';
 $strFileNameTemplateRemember = 'ingat konvensi';
 $strFixed = 'telah diperbaiki';
@@ -320,7 +314,6 @@ $strIgnoreInserts = 'Gunakan perintah INSERT dengan mengabaikan kesalahan';
 $strIgnoringFile = 'Abaikan file %s';
 $strImportDocSQL = 'Impor file docSQL';
 $strImportFiles = 'Impor file';
-$strImportFinished = 'Impor selesai';
 $strIndexes = 'Indeks';
 $strIndexHasBeenDropped = 'Indeks %s telah dihapus';
 $strIndex = 'Indeks';
@@ -343,7 +336,6 @@ $strInsecureMySQL = 'File konfigurasi Anda ditentukan dengan pengguna Root dan t
 $strInsertAsNewRow = 'Sisipkan sebagai baris baru';
 $strInsertedRowId = 'Menyisip baris id:';
 $strInsertedRows = 'Baris yang disisipkan:';
-$strInsertNewRow = 'Sisipkan baris baru';
 $strInsert = 'Sisipkan';
 $strInternalNotNecessary = '* Relasi internal tidak dibutuhkan bila ia telah berada dalam InnoDB.';
 $strInternalRelations = 'Relasi internal';
@@ -426,9 +418,7 @@ $strMyISAMSortBufferSizeDesc = 'Buffer yang dialokasikan bila menyortir indeks M
 $strMyISAMSortBufferSize = 'Urutkan ukuran Buffer';
 $strMySQLCharset = 'Charset MySQL';
 $strMySQLConnectionCollation = 'Penyortiran koneksi MySQL';
-$strMySQLReloaded = 'MySQL telah di-reload.';
 $strMySQLSaid = 'MySQL menyatakan: ';
-$strMySQLServerProcess = 'MySQL versi %pma_s1% dijalankan pada %pma_s2% sebagai %pma_s3%';
 $strMySQLShowProcess = 'Tampilkan Proses';
 $strMySQLShowStatus = 'Tampilkan informasi runtime MySQL';
 $strMySQLShowVars = 'Tampilkan variabel sistem MySQL';
@@ -546,6 +536,7 @@ $strPrivDescUpdate = 'Mengizinkan untuk ubah data.';
 $strPrivDescUsage = 'Tanpa Hak Istimewa (Privileges).';
 $strPrivileges = 'Hak Akses';
 $strPrivilegesReloaded = 'Sukses reload Hak Istimewa (Privileges).';
+$strProcesses = 'Proses Aktif';
 $strProcesslist = 'Daftar proses';
 $strPutColNames = 'Letakkan nama Fields pada baris pertama';
 
@@ -570,9 +561,7 @@ $strRelationNotWorking = 'Fasilitas penambahan untuk bekerja dengan tabel yang d
 $strRelationsForTable = 'RELASI UNTUK TABEL';
 $strRelations = 'Tabel Relasi';
 $strRelationView = 'Tampilan relasi';
-$strReloadFailed = 'Gagal memanggil ulang tabel pengguna.';
 $strReloadingThePrivileges = 'Reload Hak Istimewa (Privileges)';
-$strReloadMySQL = 'Panggil ulang tabel pengguna';
 $strRemoveSelectedUsers = 'Hapus pengguna yang dipilih';
 $strRenameDatabaseOK = 'Nama database %s telah diubah menjadi %s';
 $strRenameTableOK = 'Nama tabel %s telah diubah menjadi %s';
@@ -629,7 +618,6 @@ $strServerNotResponding = 'Server tidak menjawab';
 $strServer = 'Server';
 $strServerStatus = 'Informasi Runtime';
 $strServerStatusUptime = 'MySQL server ini telah berjalan secara berturut-turut selama %s. Server dijalankan pada tanggal %s.';
-$strServerTabProcesslist = 'Proses Aktif';
 $strServerTabVariables = 'Variabel';
 $strServerTrafficNotes = '<b>Server traffic</b>: Tabel ini menampilkan statistik jaringan lalu-lintas server MySQL sejak dihidupkan.';
 $strServerVars = 'Variabel dan penyetelan server';
@@ -658,7 +646,6 @@ $strSort = 'Urutkan';
 $strSpaceUsage = 'Penggunaan tempat';
 $strSpanish = 'Bahasa Spanyol';
 $strSplitWordsWithSpace = 'Kata dipisahkan oleh karakter spasi (" ").';
-$strSQLExportCompatibility = 'Kompatibilitas terhadap pengeksporan SQL';
 $strSQLExportType = 'Jenis Ekspor';
 $strSQLOptions = 'Pilihan SQL';
 $strSQLParserBugMessage = 'Mungkin Anda telah temukan sebuah Bug dalam parser SQL. Mohon periksa ulang pencarian SQL dengan teliti dan perhatikan apakah seluruh tanda kutip benar dan seimbang. Penyebab kegagalan bisa terjadi bila Anda meng-upload sebuah file binari diluar teks kutipan. Silakan menjalankan ulang pencarian tersebut dengan menggunakan command line interface. Hasil dari MySQL server error, jika tertampil, akan menolong Anda untuk mengetahui penyebab dari masalah ini. Bila masalah ini tetap muncul atau Parser dari kami masih juga gagal meskipun pencarian melalui command line interface berhasil mohon kurangi input pada SQL query sampai pencarian yang menyebabkan masalah ini ditemukan. Mohon kirimkan sebuah Bug Report dengan cara menyisipkan data di bagian bawah ini kepada kami:';
@@ -678,7 +665,6 @@ $strStorageEngine = 'Mesin Penyimpan';
 $strStorageEngines = 'Mesin Penyimpan';
 $strStrucCSV = 'Data CSV';
 $strStrucData = 'Struktur dan data';
-$strStrucDrop = 'Berikut \'HAPUS TABEL\'';
 $strStrucExcelCSV = 'CSV untuk data MS Excel';
 $strStrucNativeExcel = 'Data asli MS Excel';
 $strStrucOnly = 'Struktur saja';
@@ -702,7 +688,6 @@ $strTableOptions = 'Pilihan untuk tabel';
 $strTables = 'tabel %s';
 $strTableStructure = 'Struktur dari tabel';
 $strTable = 'Tabel';
-$strTableType = 'Jenis tabel';
 $strTakeIt = 'ambil';
 $strTblPrivileges = 'Hak (privileges) khusus terhadap tabel';
 $strTextAreaLength = ' Disebabkan ukuran panjangnya,<br /> field ini tidak dapat di-edit ulang. ';
@@ -719,7 +704,7 @@ $strTraditionalChinese = 'Bahasa Cina tradisional';
 $strTraditionalSpanish = 'Spanyol tradisional';
 $strTraffic = 'Lalu-Lintas';
 $strTransformation_application_octetstream__download = 'Tampilkan Link untuk men-download data binari dari Field. Pilihan pertama adalah nama dari file binari tersebut. Pilihan kedua adalah nama Field dari sebuah baris tabel yang memiliki nama file. Bila Anda menetapkan pilihan kedua, pilihan pertama harus ditepatkan ke sebuah string yang kosong';
-$strTransformation_application_octetstream__hex = 'Menampilkan representasi data heksadesimal.';
+$strTransformation_application_octetstream__hex = 'Menampilkan representasi data heksadesimal. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
 $strTransformation_image_jpeg__inline = 'Tampilkan Thumbnail yang bisa diklik; pilihan: lebar, tinggi dalam piksel (rasio asli dipertahankan)';
 $strTransformation_image_jpeg__link = 'Tampilkan link ke gambar ini (direct blob download, i.e.).';
 $strTransformation_image_png__inline = 'Lihat image/jpeg: inline';
@@ -790,42 +775,85 @@ $strYes = 'Ya';
 $strZeroRemovesTheLimit = 'Perhatian: Perubahan pilihan ini ke posisi 0 (zero) akan menghapus batas yang telah ditentukan.';
 $strZip = 'Dikompress dengan Zip';
 
-$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
-$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
-$strCSV = 'CSV';  //to translate
-$strImport = 'Import';  //to translate
-$strImportFormat = 'Format of imported file';  //to translate
-$strFileToImport = 'File to import';  //to translate
-$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
-$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
-$strPartialImport = 'Partial import';  //to translate
+// To translate:
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
-$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
-$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
-$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
-$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
-$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
-$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
-$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
-$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
-$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
+
+$strBookmarkCreated = 'Bookmark %s created';  //to translate
+$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+
+$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
+$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strCSV = 'CSV';  //to translate
+$strCSVImportOptions = 'CSV options';  //to translate
+
+$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
+
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
+$strEsperanto = 'Esperanto';  //to translate
+
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strFileToImport = 'File to import';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
 $strFlushTables = 'Flush (close) all tables';  //to translate
+
 $strHandler = 'Handler';  //to translate
+
+$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
+$strImportFormat = 'Format of imported file';  //to translate
+$strImport = 'Import';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
+$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+
 $strJoins = 'Joins';  //to translate
+
 $strKeyCache = 'Key cache';  //to translate
+
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLDI = 'CSV using LOAD DATA';  //to translate
+$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
+$strLDILocal = 'Use LOCAL keyword';  //to translate
+
 $strMaxConnects = 'max. concurrent connections';  //to translate
+$strMaximalQueryLength = 'Maximal length of created query';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+
+$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
+$strNumberOfFields = 'Number of fields';  //to translate
+
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+
+$strPartialImport = 'Partial import';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+
 $strQueryCache = 'Query cache';  //to translate
+
+$strReloadPrivileges = 'Reload privileges';  //to translate
 $strReplication = 'Replication';  //to translate
+$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
+
 $strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
+$strShowingBookmark = 'Showing bookmark';  //to translate
 $strShowOpenTables = 'Show open tables';  //to translate
 $strShowSlaveHosts = 'Show slave hosts';  //to translate
 $strShowSlaveStatus = 'Show slave status';  //to translate
-$strShowStatusReset = 'Reset';  //to translate
 $strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
 $strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
 $strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
@@ -877,13 +905,13 @@ $strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to t
 $strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
 $strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
 $strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
-$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
 $strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
+$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
 $strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
 $strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
 $strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
-$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
 $strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
@@ -899,10 +927,10 @@ $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key b
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
 $strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
 $strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
-$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
 $strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
 $strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
@@ -911,11 +939,12 @@ $strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been
 $strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
 $strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
 $strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
+$strShowStatusReset = 'Reset';  //to translate
 $strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
 $strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
 $strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
-$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
 $strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
+$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
 $strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
 $strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
 $strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
@@ -932,23 +961,56 @@ $strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache.
 $strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
 $strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
 $strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
+$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strSorting = 'Sorting';  //to translate
-$strTempData = 'Temporary data';  //to translate
-$strThreads = 'Threads';  //to translate
-$strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDILocal = 'Use LOCAL keyword';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
-$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strSQLCompatibility = 'SQL compatibility mode';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+
 $strTableAlreadyExists = 'Table %s already exists!';  //to translate
+$strTempData = 'Temporary data';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strThreads = 'Threads';  //to translate
+$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
+$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
+$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
 $strTransactionCoordinator = 'Transaction coordinator';  //to translate
-$strNumberOfFields = 'Number of fields';  //to translate
-$strShowingBookmark = 'Showing bookmark';  //to translate
-$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
-$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
-$strMaximalQueryLength = 'Maximal length of created query';  //to translate
-$strBookmarkCreated = 'Bookmark %s created';  //to translate
-$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
-$strEsperanto = 'Esperanto';  //to translate
+
+$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
+$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
+
+$strQueryResultsOperations = 'Query results operations';  //to translate
+$strAddClause = 'Add %s';  //to translate
+$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
+$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
+$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
+$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
+$strXMLOptions = 'XML options';  //to translate
+$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
+$strCreateUserDatabase = 'Database for user';  //to translate
+$strCreateUserDatabaseNone = 'None';  //to translate
+$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strOpenDocumentText = 'Open Document Text';  //to translate
+$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
+$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
+$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
+$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
+$strInvalidTableName = 'Invalid table name';  //to translate
+$strInvalidDatabase = 'Invalid database';  //to translate
+$strServers = 'Servers';  //to translate
+$strDelimiter = 'Delimiter';  //to translate
+$strFunctions = 'Functions';  //to translate
+$strProcedures = 'Procedures';  //to translate
+$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
+$strFontSize = 'Font size';  //to translate
+$strLanguage = 'Language';  //to translate
 ?>
