@@ -1,5 +1,5 @@
 <?php
-/* $Id: japanese-euc.inc.php,v 2.127.2.3 2006/03/23 17:42:14 lem9 Exp $ */
+/* $Id: japanese-euc.inc.php,v 2.151.2.2 2006/08/30 10:43:14 nijel Exp $ */
 
 /**
  * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
@@ -9,12 +9,12 @@
 
 $charset = 'euc-jp';
 $text_dir = 'ltr';
-$left_font_family = '"MS PGochic", Osaka, verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = '"MS PGochic", Osaka, arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('Х', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
+$byteUnits = array('Х', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
+
+$mysql_4_1_doc_lang = 'ja';
 
 $day_of_week = array('', '', '', '', '', '', '');
 $month = array('1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 ');
@@ -27,18 +27,17 @@ $strAbortedClients = 'Ǥޤ';
 $strAbsolutePathToDocSqlDir = 'docSQL ؤХѥꤷƤ';
 $strAccessDenied = 'ϵݤޤ';
 $strAccessDeniedCreateConfig = '餯ͳϡեƤʤǤ%1$såȥåץץ%2$s ѤƤҤȤĺ뤳ȤǤޤ';
-$strAccessDeniedExplanation = 'phpMyAdmin ϡMySQL С³褦ȤޤơС³䤷ޤconfig.inc.php Υۥȡ桼̾ӥѥɤåMySQL СδԤͿ줿뤳Ȥǧ٤Ǥ';
+$strAccessDeniedExplanation = 'MySQL Ф³褦Ȥޤ³䤵ޤconfig.inc.php Υۥȡ桼ӥѥɤMySQL ФδԤͿ줿Ȱפ뤫ǧƤ';
 $strAction = '';
 $strAddAutoIncrement = 'AUTO_INCREMENTͤɲä';
+$strAddClause = '%sɲ';
 $strAddConstraints = '¤ɲä';
 $strAddDeleteColumn = 'եɲá';
 $strAddDeleteRow = 'Ԥɲá';
-$strAddDropDatabase = 'DROP DATABASEפɲä';
 $strAddedColumnComment = 'Υɲäޤ';
 $strAddedColumnRelation = 'Υ졼ɲäޤ';
 $strAddFields = '%s ĤΥեɤɲä';
 $strAddHeaderComment = 'إåإॳȤɲ (\\n ǲ)';
-$strAddIfNotExists = 'IF NOT EXISTSפɲä';
 $strAddIntoComments = 'ɲå';
 $strAddNewField = 'եɤɲä';
 $strAddPrivilegesOnDb = 'ǡ١øɲä';
@@ -49,11 +48,11 @@ $strAddUser = '桼ɲä';
 $strAddUserMessage = '桼ɲäޤ';
 $strAdministration = '';
 $strAffectedRows = 'ƶ줿Կ:';
+$strAfter = 'ꥫθ %s';
 $strAfterInsertBack = '';
 $strAfterInsertNewInsert = '쥳ɤɲä';
 $strAfterInsertNext = 'ιԤԽ';
 $strAfterInsertSame = 'Υڡ';
-$strAfter = 'ꥫθ %s';
 $strAll = '';
 $strAllowInterrupt = '»֤ŤƤ뤳Ȥ򥹥ץȤΤ硢ݡȤؤγߤĤޤ礭ʥե򥤥ݡȤΤ褤ʤ⤷ޤ󤬡ϥȥ󥶥Ȥˤʤޤ';
 $strAllTableSameWidth = '٤ƤΥơ֥Ʊɽޤ?';
@@ -61,7 +60,7 @@ $strAlterOrderBy = 'ơ֥֤ξ';
 $strAnalyzeTable = 'ơ֥ʬϤ';
 $strAnd = 'AND';
 $strAndThen = 'Ƥθ';
-$strAnIndex = 'ǥå%sפɲäƤޤ';
+$strAnIndex = 'ǥå%sɲäƤޤ';
 $strAny = '٤';
 $strAnyHost = '٤ƤΥۥ';
 $strAnyUser = '٤ƤΥ桼';
@@ -80,49 +79,51 @@ $strBack = '';
 $strBaltic = 'ХȽ';
 $strBeginCut = 'ڤ곫';
 $strBeginRaw = 'RAW ';
-$strBinaryDoNotEdit = ' Хʥ - Ǥޤ';
 $strBinary = ' Хʥ ';
+$strBinaryDoNotEdit = ' Хʥ - Ǥޤ';
 $strBinaryLog = 'Хʥ';
 $strBinLogEventType = '٥ȥ';
 $strBinLogInfo = '';
-$strBinLogName = '̾';
+$strBinLogName = '';
 $strBinLogOriginalPosition = 'ΰ';
 $strBinLogPosition = '';
-$strBinLogServerId = 'С ID';
+$strBinLogServerId = ' ID';
 $strBookmarkAllUsers = '٤ƤΥ桼Υ֥åޡ򥢥Ǥ';
 $strBookmarkCreated = '֥åޡ %s ޤ';
 $strBookmarkDeleted = '֥åޡ˺ޤ';
 $strBookmarkLabel = '٥';
 $strBookmarkQuery = '֥åޡƤ SQL';
-$strBookmarkReplace = '¸ߤƱ̾Υ֥åޡִ';
+$strBookmarkReplace = '¸ߤƱΥ֥åޡִ';
 $strBookmarkThis = 'SQL ֥åޡ';
 $strBookmarkView = 'ɽΤ';
 $strBrowseDistinctValues = '̤ͤɽ';
 $strBrowse = 'ɽ';
 $strBrowseForeignValues = 'ɽ';
-$strBufferPoolActivity = 'Хåեסγ';
 $strBufferPool = 'Хåեס';
+$strBufferPoolActivity = 'Хåեסγ';
 $strBufferPoolUsage = 'Хåեסλ';
 $strBufferReadMisses = 'ɤ߹ߥߥ';
 $strBufferReadMissesInPercent = '% ɤ߹ߥߥ';
-$strBufferWriteWaitsInPercent = '% ν񤭹Ԥ';
 $strBufferWriteWaits = '񤭹Ԥ';
+$strBufferWriteWaitsInPercent = '% ν񤭹Ԥ';
 $strBulgarian = '֥륬ꥢ';
 $strBusyPages = 'ӥʥڡ';
 $strBzError = ' php С Bz2 ĥƤΤ phpMyAdmin ̥פǤޤphpMyAdmin Υե졼ե <code>$cfg[\'BZipDump\']</code>  <code>FALSE</code>ꤷƤBz2 ̵ǽȤˤ php ΥС夲Ʋphp Х %s ܺ١';
 $strBzip = '"bzip "';
 
 $strCalendar = '';
+$strCanNotLoadExportPlugins = 'ݡȥץ饰ɤǤޤ󥹥ȡ뤵Ƥ뤫ǧƤ!';
 $strCanNotLoadImportPlugins = 'ݡȥץ饰ɤ߹ޤ󡣥󥹥ȡǧƤ!';
-$strCannotLogin = 'MySQL С˥Ǥޤ';
-$strCantLoadRecodeIconv = 'ʸåѴԤˤȤ߹ޤƤʤ iconv ޤ GNU recode γĥɬפǤphp ˡγĥԤäƤphpMyAdmin ǤʸåѴ򤷤ʤˤƤ';
+$strCannotLogin = 'MySQL Ф˥Ǥޤ';
 $strCantLoad = 'ʤĥҤΥեǤ,<br />PHP åƤ';
-$strCantRenameIdxToPrimary = 'ǥå̾ PRIMARY ѹǤޤ';
+$strCantLoadRecodeIconv = 'ʸåѴԤˤȤ߹ޤƤʤ iconv ޤ GNU recode γĥɬפǤphp ˡγĥԤäƤphpMyAdmin ǤʸåѴ򤷤ʤˤƤ';
+$strCantRenameIdxToPrimary = 'ǥå PRIMARY ѹǤޤ';
 $strCantUseRecodeIconv = 'iconvlibiconvrecode_string ΤδؿѤǤޤphp åƤ';
 $strCardinality = 'դͤο';
 $strCaseInsensitive = 'ѻ羮̤ʤ';
 $strCaseSensitive = 'ѻ羮̤';
 $strCentralEuropean = '衼åѸ';
+$strChange = 'ѹ';
 $strChangeCopyMode = 'ƱøäΥ桼...';
 $strChangeCopyModeCopy = '... ŤΤݻ';
 $strChangeCopyModeDeleteAndReload = ' ... 桼ơ֥뤫ŤΤø˺Ƥӥɤ';
@@ -130,12 +131,11 @@ $strChangeCopyModeJustDelete = ' ... 桼ơ֥뤫ŤΤ';
 $strChangeCopyModeRevoke = ' ... ŤΤͭø򤹤٤̵ˤǺ';
 $strChangeCopyUser = 'ѹ / 桼ԡ';
 $strChangeDisplay = 'ɽեɤǲ';
-$strChange = 'ѹ';
 $strChangePassword = 'ѥɤѹ';
 $strCharset = 'ʸå';
 $strCharsetOfFile = 'եʸå:';
-$strCharsetsAndCollations = 'ʸåȤȾȹ';
 $strCharsets = 'ʸ';
+$strCharsetsAndCollations = 'ʸåȤȾȹ';
 $strCheckAll = '٤ƥå';
 $strCheckOverhead = 'Сإåɤθ򤹤';
 $strCheckPrivs = 'øΥå򤹤';
@@ -144,7 +144,7 @@ $strCheckTable = 'ơ֥å';
 $strChoosePage = 'Խڡ򤷤Ƥ';
 $strColComFeat = '󥳥ɽǽ';
 $strCollation = 'ȹ';
-$strColumnNames = '()̾';
+$strColumnNames = '()';
 $strColumnPrivileges = 'ø';
 $strCommand = 'ޥ';
 $strComments = '';
@@ -155,26 +155,30 @@ $strCompression = '';
 $strCompressionWillBeDetected = 'ݡȤ줿ե밵̤ϡưŪ˸ΤǤ礦: %s';
 $strConfigDefaultFileError = 'ǥեɤ߹ޤǤ: "%1$s"';
 $strConfigFileError = 'phpMyAdmin եɤ߹ळȤǤޤ! <br />ʸˡ顼ȯե뤬Ĥޤ<br />Υ󥯤եľɤ߹ǡPHP Υ顼åǧƤ¿ξ硢ڤʸ䥻ߥ˺Ƥޤ<br />⤷Υڡ줿餹٤ƤޤԤäƤޤ';
-$strConfigureTableCoord = 'ơ֥%sץơ֥ĴƤ';
+$strConfigureTableCoord = 'ơ֥%sơ֥ĴƤ';
 $strConnectionError = '³Ǥޤ: ̵Ǥ';
 $strConnections = '³';
 $strConstraintsForDumped = '׺ѥơ֥';
 $strConstraintsForTable = 'ơ֥';
 $strCookiesRequired = 'ϥåĤƤɬפޤ';
 $strCopy = 'ԡ';
-$strCopyDatabaseOK = 'ǡ١%sפϡ%sפ˥ԡޤ';
+$strCopyDatabaseOK = 'ǡ١%sϡ%s˥ԡޤ';
 $strCopyTable = 'ơ֥(database<b>.</b>table)˥ԡ:';
-$strCopyTableOK = 'ơ֥%sפ%sפ˥ԡޤ';
+$strCopyTableOK = 'ơ֥%s%s˥ԡޤ';
 $strCopyTableSameNames = 'Ʊơ֥˥ԡǤޤ!';
 $strCouldNotKill = 'phpMyAdmin å %s λ뤳ȤǤޤǤ餯˽λƤޤ';
-$strCreateDatabaseBeforeCopying = 'ԡˡCREATE DATABASEפ';
+$strCreate = '';
+$strCreateDatabaseBeforeCopying = 'ԡˡCREATE DATABASE';
 $strCreateIndex = '&nbsp;%s&nbsp; Υǥå';
 $strCreateIndexTopic = 'ǥå';
 $strCreateNewDatabase = 'ǡ١';
-$strCreateNewTable = 'ǡ١%sפ˥ơ֥򿷵';
-$strCreate = '';
+$strCreateNewTable = 'ǡ١%s˥ơ֥򿷵';
 $strCreatePage = 'ڡ';
 $strCreatePdfFeat = 'PDF ǽ';
+$strCreateUserDatabase = '桼ѥǡ١';
+$strCreateUserDatabaseName = 'ƱΥǡ١Ƥ٤ƤøͿޤ';
+$strCreateUserDatabaseNone = 'ʤ';
+$strCreateUserDatabaseWildcard = '磻ɥɤǻꤵ줿ǡ١ˤ٤ƤøͿޤ(桼_%)';
 $strCreationDates = '//դɲä';
 $strCriteria = 'ʹߴ';
 $strCroatian = '';
@@ -186,23 +190,23 @@ $strCzech = '';
 $strCzechSlovak = 'ΥХ';
 
 $strDanish = 'ǥޡ';
+$strData = 'ǡ';
 $strDatabase = 'ǡ١';
-$strDatabaseEmpty = 'ǡ١̾Ǥ!';
+$strDatabaseEmpty = 'ǡ١Ǥ!';
 $strDatabaseExportOptions = 'ǡ١ݡȥץ';
-$strDatabaseHasBeenDropped = 'ǡ١%sפ˺ޤ';
+$strDatabaseHasBeenDropped = 'ǡ١%s˺ޤ';
 $strDatabaseNoTable = 'Υǡ١ϥơ֥ޤǤޤ!';
 $strDatabases = 'ǡ١';
-$strDatabasesDropped = 'ǡ١%sפϺޤ';
+$strDatabasesDropped = 'ǡ١%sϺޤ';
 $strDatabasesStats = 'ǡ١';
 $strDatabasesStatsDisable = 'פ̵ˤ';
 $strDatabasesStatsEnable = 'פĤ';
-$strDatabasesStatsHeavyTraffic = ': ǡ١פĤ MySQL  WEBСδ֤ǽŤȥեåȯ뤫⤷ޤ';
-$strData = 'ǡ';
+$strDatabasesStatsHeavyTraffic = ': ǡ١פĤ MySQL  WEBФδ֤ǽŤȥեåȯ뤫⤷ޤ';
 $strDataDict = 'ǡ';
 $strDataOnly = 'ǡΤ';
 $strDataPages = 'ǡޤڡ';
 $strDBComment = 'ǡ١Υ: ';
-$strDBCopy = '̾ǥǡ١򥳥ԡ';
+$strDBCopy = 'ǥǡ١򥳥ԡ';
 $strDBGContext = 'ƥ';
 $strDBGContextID = 'ƥID';
 $strDBGHits = 'ҥå';
@@ -213,20 +217,21 @@ $strDBGModule = '⥸塼';
 $strDBGTimePerHitMs = 'ҥåΨ(ߥ)';
 $strDBGTotalTimeMs = '׻(ߥ)';
 $strDbPrivileges = 'ǡ١ ø';
-$strDBRename = '̾˥ǡ١̾ѹ';
+$strDBRename = '˥ǡ١ѹ';
 $strDbSpecific = 'ǡ١';
-$strDefaultEngine = '%s ϡ MySQL СΥǥեȥȥ졼󥸥Ǥ';
-$strDefaultValueHelp = 'ǥեͤΤˡХåå奨פʤ 1 ĤͤƲ, ΥեޥåȤ: a';
 $strDefault = '';
+$strDefaultEngine = '%s ϡ MySQL ФΥǥեȥȥ졼󥸥Ǥ';
+$strDefaultValueHelp = 'ǥեͤΤˡХåå奨פʤ 1 ĤͤƲ, ΥեޥåȤ: a';
 $strDefragment = 'ơ֥Υǥե饰';
 $strDelayedInserts = 'ٱ䥤󥵡ȤѤ';
+$strDelete = '';
 $strDeleteAndFlush = '桼øɤ';
 $strDeleteAndFlushDescr = 'ϥꥢǤøɤΤǾ֤ޤ';
 $strDeleted = '򤷤ޤ';
 $strDeletedRows = '줿Կ:';
 $strDeleteNoUsersSelected = '桼򤷤Ƥޤ!';
-$strDelete = '';
 $strDeleting = '%s Ǥ';
+$strDelimiter = 'ǥߥ';
 $strDelOld = 'ߤΥڡϡϤ¸ߤʤơ֥˻ȤޤλȤǤ?';
 $strDescending = '߽';
 $strDescription = '';
@@ -240,9 +245,9 @@ $strDisplayPDF = 'PDF ޤɽ򤹤';
 $strDoAQuery = '"QUERY"¹ (磻ɥ: "%")';
 $strDocu = 'ɥ';
 $strDoYouReally = '˼¹ԤƤɤǤ?:';
-$strDropDatabaseStrongWarning = '˥ǡ١˲Ǥ礦!';
 $strDrop = '';
-$strDropUsersDb = '桼Ʊ̾ĥǡ١';
+$strDropDatabaseStrongWarning = '˥ǡ١˲Ǥ礦!';
+$strDropUsersDb = '桼Ʊĥǡ١';
 $strDumpingData = 'ơ֥Υץǡ';
 $strDumpSaved = 'פե %s ¸ޤ';
 $strDumpXRows = '%s פޤ %s Ǥ';
@@ -257,18 +262,19 @@ $strEmptyResultSet = 'MySQL ֤ͤޤ (㤨йԤä)';
 $strEnabled = 'ͭ';
 $strEncloseInTransaction = 'ȥ󥶥ǥݡȤϤ';
 $strEncto = '󥳡ǥ󥰤Ѵ'; // encoding convert
-$strEndCut = 'ڤ꽪λ';
 $strEnd = 'Ǹ';
+$strEndCut = 'ڤ꽪λ';
 $strEndRaw = 'RAW λ';
-$strEngineAvailable = '%s ϡ MySQL СѲǽǤ';
-$strEngineDisabled = '%s ϡ MySQL СǤ̵ˤƤޤ';
+$strEngineAvailable = '%s ϡ MySQL ФѲǽǤ';
+$strEngineDisabled = '%s ϡ MySQL ФǤ̵ˤƤޤ';
 $strEngines = '󥸥';
-$strEngineUnsupported = ' MySQL С %s ȥ졼󥸥򥵥ݡȤƤޤ';
+$strEngineUnsupported = ' MySQL Ф %s ȥ졼󥸥򥵥ݡȤƤޤ';
 $strEnglish = 'Ѹ';
-$strEnglishPrivileges = ' : MySQLø̾ϱѸɽƤޤ';
-$strErrorInZipFile = 'ZIP ˥顼Ǥ:';
+$strEnglishPrivileges = ' : MySQLøϱѸɽƤޤ';
 $strError = '顼';
-$strEscapeWildcards = '磻ɥɡ_פӡ%פϤʸ̤˻Ѥ뤿ˡ\פǥ()٤Ǥ';
+$strErrorInZipFile = 'ZIP ֤˥顼ޤ:';
+$strErrorRenamingTable = 'ơ֥%1$s%2$s˥͡हȤ˥顼ȯޤ';
+$strEscapeWildcards = '磻ɥɡ_ӡ%ʸ̤˻ѤȤϡ\ǥפƤ';
 $strEsperanto = 'ݸ';
 $strEstonian = 'ȥ˥';
 $strExcelEdition = 'Excel μ';
@@ -276,24 +282,25 @@ $strExcelOptions = 'Excel ץ';
 $strExecuteBookmarked = '֥åޡ줿Ȳ¹Ԥ';
 $strExplain = 'SQL ʬϤ';
 $strExport = 'ݡ';
+$strExportMustBeFile = 'Υݡȷϥե¸ɬפޤ!';
 $strExtendedInserts = 'ĥ INSERT ʸ';
 $strExtra = '¾';
 
 $strFailedAttempts = 'ߤϼԤޤ';
-$strFieldHasBeenDropped = 'ե %s ˺ޤ';
 $strField = 'ե';
+$strFieldHasBeenDropped = 'ե %s ˺ޤ';
+$strFields = 'ե';
 $strFieldsEmpty = ' եɿǤ ';
 $strFieldsEnclosedBy = 'եɰϤߵ';
 $strFieldsEscapedBy = 'եɤΥ׵';
-$strFields = 'ե';
 $strFieldsTerminatedBy = 'եɶڤ국';
-$strFileAlreadyExists = 'ե%sפϴ˥С¸ߤޤե̾ѹ뤫񤭥ץǧƤ';
+$strFileAlreadyExists = 'ե%sϴ˥Ф¸ߤޤեѹ뤫񤭥ץǧƤ';
 $strFileCouldNotBeRead = 'եɤޤ';
+$strFileNameTemplate = 'եΥƥץ졼';
 $strFileNameTemplateDescription = 'ͤ %1$sstrftime%2$s ѤơȽǤޤäơֽ񼰤ʸѤ뤳ȤǤޤ˼ʸִǤ礦: %3$sΤޤޤ¾ΥƥȤϰݻǤ礦';
-$strFileNameTemplateDescriptionDatabase = 'ǡ١̾';
-$strFileNameTemplateDescriptionServer = 'С̾';
-$strFileNameTemplateDescriptionTable = 'ơ֥̾';
-$strFileNameTemplate = 'ե̾Υƥץ졼';
+$strFileNameTemplateDescriptionDatabase = 'ǡ١';
+$strFileNameTemplateDescriptionServer = '';
+$strFileNameTemplateDescriptionTable = 'ơ֥';
 $strFileNameTemplateRemember = 'ƥץ졼ȤФ';
 $strFileToImport = 'ե򥤥ݡȤ';
 $strFixed = '';
@@ -301,11 +308,13 @@ $strFlushPrivilegesNote = ': phpMyAdmin  MySQL øơ֥뤫ľܤ˥桼øޤ⤷ޥ˥奢
 $strFlushQueryCache = 'Ȳ񥭥åեå夹';
 $strFlushTable = 'ơ֥Υåˤ("FLUSH")';
 $strFlushTables = '٤ƤΥơ֥եå夹(Ĥ)';
+$strFontSize = 'եȥ';
 $strFormat = 'եޥå';
 $strFormEmpty = 'եǤͤޤǤ';
 $strFreePages = 'ե꡼ʥڡ';
 $strFullText = 'ʸ';
 $strFunction = 'ؿ';
+$strFunctions = 'ؿ';
 
 $strGenBy = 'Ķ';
 $strGeneralRelationFeat = '졼ǽ';
@@ -330,8 +339,8 @@ $strHebrew = 'إ֥饤';
 $strHexForBinary = 'Хʥեɤ 16 ʿѤ';
 $strHome = 'ᥤڡ';
 $strHomepageOfficial = 'phpMyAdmin ۡ';
-$strHostEmpty = 'ۥ̾϶Ǥ!';
 $strHost = 'ۥ';
+$strHostEmpty = 'ۥȤ϶Ǥ!';
 $strHTMLExcel = 'Microsoft Excel 2000';
 $strHTMLExcelOptions = 'Microsoft Excel 2000 ݡȥץ';
 $strHTMLWord = 'Microsoft Word 2000';
@@ -341,24 +350,24 @@ $strHungarian = 'ϥ󥬥꡼';
 $strIcelandic = 'ɸ';
 $strId = 'ID';
 $strIdxFulltext = 'ʸ';
-$strIgnoreDuplicates = 'Ԥʣ̵뤹';
 $strIgnore = '̵';
-$strIgnoreInserts = 'INSERT IGNOREפѤ';
+$strIgnoreDuplicates = 'Ԥʣ̵뤹';
+$strIgnoreInserts = 'INSERT IGNOREѤ';
 $strIgnoringFile = 'ե̵ %s';
+$strImport = 'ݡ';
 $strImportDocSQL = 'docSQL ե륤ݡ';
 $strImportFiles = 'ݡȥե';
 $strImportFormat = 'ݡȺѥեν';
-$strImport = 'ݡ';
 $strImportSuccessfullyFinished = 'ݡȤޤ%d ĤξȲ¹Ԥޤ';
+$strIndex = 'ǥå';
 $strIndexes = 'ǥå';
 $strIndexHasBeenDropped = 'ǥå %s ޤ';
-$strIndexName = 'ǥå̾&nbsp;:';
-$strIndex = 'ǥå';
+$strIndexName = 'ǥå&nbsp;:';
 $strIndexType = 'ǥåμ&nbsp;:';
 $strIndexWarningMultiple = '1 Ĥۤ INDEX  `%s` Ѥ˺ޤ';
-$strIndexWarningPrimary = 'PRIMARY  INDEX ΥξȤ⡢ `%s` ꤵ٤ǤϤޤ';
+$strIndexWarningPrimary = ' `%s`  PRIMARY  INDEX ΥξȤꤹΤϤ褷ޤ礦';
 $strIndexWarningTable = 'ơ֥ `%s` Υǥå˴ؤǤ';
-$strIndexWarningUnique = 'UNIQUE  INDEX ΥξȤ⡢ `%s` ꤵ٤ǤϤޤ';
+$strIndexWarningUnique = ' `%s`  UNIQUE  INDEX ΥξȤꤹΤϤ褷ޤ礦';
 $strInnoDBAutoextendIncrementDesc = ' 줬äѤˤʤˡưĥơ֥륹ڡΥĥ뤿ʬ̤Ǥ';
 $strInnoDBAutoextendIncrement = 'ưĥɲ';
 $strInnoDBBufferPoolSize = 'Хåեѥ';
@@ -368,12 +377,11 @@ $strInnoDBDataHomeDir = 'ǡۡǥ쥯ȥ';
 $strInnoDBDataHomeDirDesc = '٤Ƥ InnoDB ǡեѤΥǥ쥯ȥѥζʬǤ';
 $strInnoDBPages = 'ڡ';
 $strInnodbStat = 'InnoDB ơ';
-$strInsecureMySQL = 'ʤΥե졼ե꤬ MySQL ǥեȤøȤˤʤäƤޤ (root 桼ǥѥɤʤ)  MySQL С⤳ΥǥեưƤΤǡԤФ̵ǤΥƥۡɬĤƤ';
-$strInsert = 'ɲ';
+$strInsecureMySQL = 'ʤΥե졼ե꤬ MySQL ǥեȤøȤˤʤäƤޤ (root 桼ǥѥɤʤ)  MySQL Ф⤳ΥǥեưƤΤǡԤФ̵ǤΥƥۡɬĤƤ';
 $strInsertAsNewRow = 'ԤȤɲä';
 $strInsertedRowId = '󥵡Ȥ ID:';
 $strInsertedRows = 'ɲä줿Կ:';
-$strInsertNewRow = 'Ԥɲä';
+$strInsert = 'ɲ';
 $strInternalNotNecessary = '* InnoDB ¸ߤ硢졼ɬפǤϤޤ';
 $strInternalRelations = '졼';
 $strInUse = '';
@@ -383,28 +391,31 @@ $strInvalidColumnCount = ' 0 礭ʤФޤ';
 $strInvalidCSVFieldCount = 'CSV  ̵ʹܿޤ(:%d)';
 $strInvalidCSVFormat = 'CSV  ̵ʽ񼰤ޤ(:%d)';
 $strInvalidCSVParameter = 'CSV ݡȤΥѥ᡼̵Ǥ: %s';
+$strInvalidDatabase = 'ǡ١Ǥ';
 $strInvalidFieldAddCount = 'ʤȤҤȤĤΥեɤɲäʤФʤޤ';
 $strInvalidFieldCount = 'ơ֥ϾʤȤҤȤĤΥեɤɬפǤ';
 $strInvalidLDIImport = 'Υץ饰ϰ̺ѥݡȤ򥵥ݡȤƤޤ!';
 $strInvalidRowNumber = '%d ʤֹǤ';
-$strInvalidServerHostname = 'С%1$sפΥۥ̵̾ǤĴƤ';
-$strInvalidServerIndex = '̵ʥСǥåǤ: "%s"';
+$strInvalidServerHostname = 'С%1$sΥۥȤ̵ǤĴƤ';
+$strInvalidServerIndex = '̵ʥХǥåǤ: "%s"';
+$strInvalidTableName = 'ơ֥뤬Ǥ';
 
 $strJapanese = 'ܸ';
 $strJoins = '';
 $strJumpToDB = '&quot;%s&quot; ǡ١إ.';
 $strJustDelete = 'øơ֥뤫桼¨';
-$strJustDeleteDescr = '&quot;&quot; 桼øɤޤǥС˥ǽǤ';
+$strJustDeleteDescr = '&quot;&quot; 桼øɤޤǥФ˥ǽǤ';
 
 $strKanjiEncodConvert = 'Ѵ'; // kanji code convert
 $strKeepPass = 'ѥɤѹʤ';
 $strKeyCache = 'å';
-$strKeyname = '̾';
+$strKeyname = '';
 $strKill = '';
 $strKorean = 'ڹ';
 
 $strLandscape = 'ɥ';
-$strLanguageFileNotFound = 'ե%1$sפĤޤ';
+$strLanguage = '';
+$strLanguageFileNotFound = 'ե%1$sĤޤ';
 $strLanguageUnknown = 'θ: %1$s.';
 $strLatchedPages = 'åƤڡ';
 $strLatexCaption = 'ơ֥륭ץ';
@@ -428,12 +439,12 @@ $strLinksTo = '';
 $strLithuanian = 'ȥ˥';
 $strLocalhost = '';
 $strLocationTextfile = 'ƥȥեξ';
-$strLoginInformation = '';
 $strLogin = '';
+$strLoginInformation = '';
 $strLogout = '';
 $strLogPassword = 'ѥ:';
-$strLogServer = 'С';
-$strLogUsername = '桼̾:';
+$strLogServer = '';
+$strLogUsername = '桼:';
 $strLongOperation = 'ϻ֤ޤǤʤߤޤ?';
 
 $strMaxConnects = '¹³';
@@ -446,31 +457,31 @@ $strMIME_available_transform = 'Ѵͭ';
 $strMIME_description = '';
 $strMIME_MIMEtype = 'MIME ';
 $strMIME_nodescription = 'Ѵˤͭޤ<br />Ԥ%sΰ̣򤴳ǧ';
-$strMIME_transformation_note = 'ѲǽѴץΰӤ MIME Ѵ˴ؤƤϡ%sѴ%s 򥯥åƤ';
 $strMIME_transformation = '֥饦Ѵ';
+$strMIME_transformation_note = 'ѲǽѴץΰӤ MIME Ѵ˴ؤƤϡ%sѴ%s 򥯥åƤ';
 $strMIME_transformation_options = 'Ѵץ';
-$strMIME_transformation_options_note = 'ν񼰤ѤơѴץͤϤƤ: \'a\',\'b\',\'c\'...<br />Хåå("\")䥷󥰥륯("\'")ͤ˴ޤɬפ(\\\\xyzפa\\\'bפΤ褦)ХååǥפƤ';
+$strMIME_transformation_options_note = 'ν񼰤ѤơѴץͤϤƤ: \'a\',\'b\',\'c\'...<br />Хåå("\")䥷󥰥륯("\'")ͤ˴ޤɬפ(\\\\xyza\\\'bΤ褦)ХååǥפƤ';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';
 $strMIME_without = 'åΤǰ줿 MIME פϸ̤ѴؿäƤޤ';
 $strModifications = 'ޤ';
-$strModifyIndexTopic = 'ǥåѹ';
 $strModify = '';
+$strModifyIndexTopic = 'ǥåѹ';
 $strMoveTable = 'ơ֥(database<b>.</b>table)˰ư:';
-$strMoveTableOK = 'ơ֥%sפ%sפ˰ưޤ';
+$strMoveTableOK = 'ơ֥%s%s˰ưޤ';
 $strMoveTableSameNames = 'Ʊơ֥˰ưǤޤ!';
 $strMultilingual = '¿';
 $strMyISAMDataPointerSize = 'ǡΥݥ󥿡';
 $strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAM ơ֥˻Ѥ MAX_ROWS ץ󤬻ꤵʤΥХȻΥǥեȥݥ󥿡Ǥ';
-$strMyISAMMaxExtraSortFileSizeDesc = 'MyISAMΥǥå®ȤѤƥݥե礭åѤȤꤳ˻ꤷͰʾ礭ʤϡåˡȤޤ';
 $strMyISAMMaxExtraSortFileSize = 'ǥåѰեκ祵';
-$strMyISAMMaxSortFileSizeDesc = 'MyISAM ǥåκƺǻѤ뤳Ȥ줿 MySQL եκ祵Ǥ (REPAIR TABLE 桢ALTER TABLE  LOAD DATA INFILE)';
+$strMyISAMMaxExtraSortFileSizeDesc = 'MyISAMΥǥå®ȤѤƥݥե礭åѤȤꤳ˻ꤷͰʾ礭ʤϡåˡȤޤ';
 $strMyISAMMaxSortFileSize = 'ȥեκ祵';
-$strMyISAMRecoverOptionsDesc = 'å夷 MyISAM ơ֥μưѥ⡼ɤǡСưץ --myisam-recover ꤷޤ';
+$strMyISAMMaxSortFileSizeDesc = 'MyISAM ǥåκƺǻѤ뤳Ȥ줿 MySQL եκ祵Ǥ (REPAIR TABLE 桢ALTER TABLE  LOAD DATA INFILE)';
+$strMyISAMRecoverOptionsDesc = 'å夷 MyISAM ơ֥μưѥ⡼ɤǡеưץ --myisam-recover ꤷޤ';
 $strMyISAMRecoverOptions = 'ư⡼';
 $strMyISAMRepairThreads = 'åɤν';
 $strMyISAMRepairThreadsDesc = '⤷ͤ 1 ʾʤ顢MyISAM ơ֥ΥǥåϥȽνʿԤ(켫Ȥγƥǥå)ޤ';
-$strMyISAMSortBufferSizeDesc = 'ΥХåեϡREPAIR TABLE δ֤ MyISAM ǥå򥽡Ȥ硢ޤ CREATE INDEX  ALTER TABLE ȥǥåˡդޤ';
 $strMyISAMSortBufferSize = 'ȥХåե';
+$strMyISAMSortBufferSizeDesc = 'ΥХåեϡREPAIR TABLE δ֤ MyISAM ǥå򥽡Ȥ硢ޤ CREATE INDEX  ALTER TABLE ȥǥåˡդޤ';
 $strMySQLCharset = 'MySQL ʸå';
 $strMysqlClientVersion = 'MySQL 饤ȥС';
 $strMySQLConnectionCollation = 'MySQL ³ȹ';
@@ -479,14 +490,16 @@ $strMySQLShowProcess = 'MySQL ץɽ';
 $strMySQLShowStatus = 'MySQL Υ󥿥';
 $strMySQLShowVars = 'MySQL Υƥѿ';
 
-$strName = '̾';
+$strName = '';
 $strNext = '';
+$strNo = '';
 $strNoActivity = '%s ðʾ򤷤ޤǤ٥򤷤Ƥ';
 $strNoDatabases = 'ǡ١';
 $strNoDatabasesSelected = 'ǡ١򤵤Ƥޤ';
+$strNoDataReceived = 'ݡȤǡǤޤǤե뤬Ƥʤե륵PHPǵĤ줿ͤĶƤޤFAQ 1.16';
 $strNoDescription = 'Ҥޤ';
 $strNoDetailsForEngine = 'Υȥ졼󥸥ˤͭʥơξܺپϤޤ';
-$strNoDropDatabases = 'DROP DATABASEץơȥȤ϶ػߤ';
+$strNoDropDatabases = 'DROP DATABASEơȥȤ϶ػߤ';
 $strNoExplain = 'SQL ʬϤФ';
 $strNoFilesFoundInZip = 'ZIP ˥ե뤬Ĥޤ!';
 $strNoFrames = 'phpMyAdmin <b>ե졼</b>򥵥ݡȤ֥饦ǤѤ򤪴ᤷޤ';
@@ -496,19 +509,17 @@ $strNoModification = 'ѹ̵';
 $strNone = '̵';
 $strNoOptions = 'ν񼰤ϥץ󤬤ޤ';
 $strNoPassword = 'ѥ̵';
-$strNoPermission = 'ե%sפ¸ѡߥå򥦥֥СϻäƤޤ';
+$strNoPermission = 'ե%s¸ѡߥå򥦥֥ФϻäƤޤ';
 $strNoPhp = 'PHP ̵';
 $strNoPrivileges = 'ø̵';
 $strNoRights = 'øäƤʤΤǤޤ';
 $strNoRowsSelected = 'Ԥ򤵤ޤǤ';
-$strNo = '';
-$strNoSpace = 'ե%sפ¸ˤ϶̤ԽʬǤ';
+$strNoSpace = 'ե%s¸ˤ϶̤ʬǤ';
 $strNoTablesFound = 'ߤΥǡ١˥ơ֥Ϥޤ';
-$strNoThemeSupport = 'ơޤ򥵥ݡȤƤޤȥơޥǥ쥯ȥ%sפǧƤ';
-$strNothingToImport = 'ĤΥǡϥݡȤƤޤ!';
+$strNoThemeSupport = 'ơޤ򥵥ݡȤƤޤȥơޥǥ쥯ȥ%sǧƤ';
 $strNotNumber = 'ϿͤǤϤޤ';
 $strNotOK = 'OK ǤϤޤ';
-$strNotSet = 'ơ֥<b>%s</b>פĤʤ%s ꤵƤޤ';
+$strNotSet = 'ơ֥<b>%s</b>Ĥʤ%s ꤵƤޤ';
 $strNoUsersFound = '桼ϸĤޤǤ';
 $strNoValidateSQL = 'SQL ڤ򥹥å';
 $strNull = '(NULL)';
@@ -518,6 +529,10 @@ $strNumSearchResultsTotal = '<b>:</b> <i>%s</i> Ĥޤ';
 $strNumTables = 'ơ֥';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheet = 'ץåɥȤ򳫤';
+$strOpenDocumentSpreadsheetOptions = 'ץåɥȤ򳫤ȤΥץ';
+$strOpenDocumentText = 'ƥȤ򳫤';
+$strOpenDocumentTextOptions = 'ƥȤ򳫤ȤΥץ';
 $strOpenNewWindow = ' phpMyAdmin Υɥ򳫤';
 $strOperations = '';
 $strOperator = '';
@@ -531,17 +546,18 @@ $strPagesToBeFlushed = 'եå夵줿ڡ';
 $strPaperSize = '極';
 $strPartialImport = 'ʬŪʥݡ';
 $strPartialText = 'ʬŪʸ';
+$strPassword = 'ѥ';
 $strPasswordChanged = '%s Υѥɤѹޤ';
 $strPasswordEmpty = 'ѥɤǤ';
 $strPasswordHashing = 'ѥɥϥå';
-$strPassword = 'ѥ';
 $strPasswordNotSame = 'ѥɤƱǤϤޤ';
-$strPdfDbSchema = 'ǡ١%sפΥ - ڡ %s';
+$strPdfDbSchema = 'ǡ١%sΥ - ڡ %s';
 $strPdfInvalidTblName = '"%s" ơ֥뤬ޤ!';
 $strPdfNoTables = 'ơ֥뤬ޤ';
 $strPDFOptions = 'PDF ץ';
 $strPDF = 'PDF';
-$strPDFReportTitle = 'ݡȤ̾';
+$strPDFReportExplanation = '(ñơ֥ΥǡޤݡȤޤ)';
+$strPDFReportTitle = 'ݡȤ';
 $strPerHour = '';
 $strPerMinute = '/ʬ';
 $strPerSecond = '/';
@@ -556,13 +572,13 @@ $strPolish = 'ݡɸ';
 $strPortrait = 'ݡȥ쥤';
 $strPos1 = 'ǽ';
 $strPrevious = '';
-$strPrimaryKeyHasBeenDropped = '祭ޤ';
-$strPrimaryKeyName = '祭̾... PRIMARY ǤϤʤФޤ';
-$strPrimaryKeyWarning = '("PRIMARY"Ϥ礦ɼ祭̾ǤϤʤФޤ';
 $strPrimary = '';
+$strPrimaryKeyHasBeenDropped = '祭ޤ';
+$strPrimaryKeyName = '祭... PRIMARY ǤϤʤФޤ';
+$strPrimaryKeyWarning = '("PRIMARY"Ϥ礦ɼ祭ǤϤʤФޤ';
 $strPrint = '';
-$strPrintViewFull = 'ӥ塼 (ƥȤޤ)';
 $strPrintView = 'Ѥɽ';
+$strPrintViewFull = 'ӥ塼 (ƥȤޤ)';
 $strPrivDescAllPrivileges = 'GRANT ٤Ƥøޤߤޤ';
 $strPrivDescAlter = '¸ߤơ֥빽¤ѹĤޤ';
 $strPrivDescAlterRoutine = 'ȥɥ롼ѹ˴Ĥޤ';
@@ -570,49 +586,52 @@ $strPrivDescCreateDb = 'ǡ١ơ֥κĤޤ';
 $strPrivDescCreateRoutine = 'ȥɥ롼κĤޤ';
 $strPrivDescCreateTbl = 'ơ֥κĤޤ';
 $strPrivDescCreateTmpTable = 'ƥݥ꡼ơ֥κĤޤ';
-$strPrivDescCreateUser = '桼Ȥκ˴̾ѹĤޤ';
+$strPrivDescCreateUser = '桼Ȥκ˴ѹĤޤ';
 $strPrivDescCreateView = 'ӥ塼κĤޤ';
 $strPrivDescDelete = 'ǡκĤޤ';
 $strPrivDescDropDb = 'ǡ١ȥơ֥κĤޤ';
 $strPrivDescDropTbl = 'ơ֥κĤޤ';
-$strPrivDescExecute = 'ȥɥץ㡼¹Ԥ뤳ȤĤޤ MySQL ǤǤϰ̣ޤ';
 $strPrivDescExecute5 = 'ȥɥ롼μ¹ԤĤޤ';
+$strPrivDescExecute = 'ȥɥץ㡼¹Ԥ뤳ȤĤޤ MySQL ǤǤϰ̣ޤ';
 $strPrivDescFile = 'ǡΥݡȡǡΥեؤΥݡȤĤޤ';
 $strPrivDescGrant = 'øơ֥Υɤʤ˥桼øɲäĤޤ';
 $strPrivDescIndex = 'ǥåκĤޤ';
 $strPrivDescInsert = 'ǡؤĤޤ';
 $strPrivDescLockTables = 'ߤΥåɤΥå󥰥ơ֥Ĥޤ';
 $strPrivDescMaxConnections = '1 ˿³ǽʿ¤ޤ';
-$strPrivDescMaxQuestions = '1 ˥С˾Ȳ¤ޤ';
+$strPrivDescMaxQuestions = '1 ˥Ф˾Ȳ¤ޤ';
 $strPrivDescMaxUpdates = '1 ˥ơ֥롢ǡ١ФƤѹȯ륳ޥɤο¤ޤ';
 $strPrivDescMaxUserConnections = '桼Ʊ³¤ޤ';
 $strPrivDescProcess3 = '¾Υ桼ץߤǤ뤳ȤĤޤ';
 $strPrivDescProcess4 = 'ץδʾȲɽĤޤ';
 $strPrivDescReferences = ' MySQL СǤϰ̣ޤ';
-$strPrivDescReload = 'СΥɡåΥꥢĤޤ';
+$strPrivDescReload = 'ФΥɡåΥꥢĤޤ';
 $strPrivDescReplClient = '졼֤ޥ׵Ǥ븢桼Ϳޤ';
 $strPrivDescReplSlave = 'ץꥱ󥹥졼֤ɬפǤ';
 $strPrivDescSelect = 'ǡɤ߽Ф';
 $strPrivDescShowDb = 'ǡ١δʰؤΥͿޤ';
 $strPrivDescShowView = 'Ȳ SHOW CREATE VIEW μ¹ԤĤޤ';
-$strPrivDescShutdown = 'СΥåȥĤޤ';
+$strPrivDescShutdown = 'ФΥåȥĤޤ';
 $strPrivDescSuper = '³ãƤ³Ĥޤ¿δϥХѿ¾桼ץνλǤ褦꤬ɬפǤ';
 $strPrivDescUpdate = 'ǡνĤޤ';
 $strPrivDescUsage = 'øޤ';
 $strPrivileges = 'ø';
 $strPrivilegesReloaded = 'øϥɤޤ';
+$strProcedures = 'ץ';
+$strProcesses = 'ץ';
 $strProcesslist = 'ץ';
 $strProtocolVersion = 'ץȥС';
-$strPutColNames = 'ǽ 1 ܤ˥ե̾ɲä';
+$strPutColNames = 'ǽ 1 ܤ˥եɤɲä';
 
+$strQBE = 'Ȳ';
 $strQBEDel = '';
 $strQBEIns = '';
-$strQBE = 'Ȳ';
 $strQueryCache = 'Ȳ񥭥å';
 $strQueryFrame = 'Ȳ񥦥ɥ';
 $strQueryOnDb = 'ǡ١ SQL <b>%s</b>:';
+$strQueryResultsOperations = 'Ȳ';
 $strQuerySQLHistory = 'SQL ';
-$strQueryStatistics = '<b>Ȳ</b>: ư %s ĤξȲ񤬥СƤޤ';
+$strQueryStatistics = '<b>Ȳ</b>: ư %s ĤξȲ񤬥ФƤޤ';
 $strQueryTime = 'Ȳμ¹Ի %01.4f ';
 $strQueryType = 'Ȳ񥿥';
 $strQueryWindowLock = 'ɥγ餳ξȲ񤭴Ǥޤ';
@@ -628,11 +647,11 @@ $strRelations = '졼';
 $strRelationsForTable = 'RELATIONS FOR TABLE';
 $strRelationView = '졼ɽ';
 $strReloadingThePrivileges = 'øɤ߹Ǥ';
-$strReloadMySQL = 'MySQL Υ';
+$strReloadPrivileges = 'MySQL Υ';
 $strRemoveSelectedUsers = '򤵤줿桼ޤ';
-$strRenameDatabaseOK = 'ǡ١%sפϡ%sפ̾ѹޤ';
-$strRenameTable = 'ơ֥̾ѹ';
-$strRenameTableOK = '%sפ%sפ̾ѹޤ';
+$strRenameDatabaseOK = 'ǡ١%sϡ%s˾ѹޤ';
+$strRenameTable = 'ơ֥ѹ';
+$strRenameTableOK = '%s%sѹޤ';
 $strRepairTable = 'ơ֥줹';
 $strReplaceNULLBy = 'NULL ʸ֤';
 $strReplaceTable = 'եǥơ֥֤';
@@ -640,9 +659,9 @@ $strReplication = 'ץꥱ';
 $strReset = 'ꥻå';
 $strResourceLimits = '꥽';
 $strReType = '';
+$strRevoke = 'ѻ';
 $strRevokeAndDelete = '桼ͭø򤹤٤˴ƺ';
 $strRevokeAndDeleteDescr = '桼øɤ߹ߤޤ USAGE øΤޤޤǤ';
-$strRevoke = 'ѻ';
 $strRevokeMessage = '%s øäޤ';
 $strRomanian = '롼ޥ˥';
 $strRowLength = 'ԤĹ';
@@ -656,13 +675,14 @@ $strRowsModeVertical = 'ľ';
 $strRowsStatistic = 'Ԥ';
 $strRunning = '¹Ǥ %s';
 $strRunQuery = 'Ȳμ¹Ԥ';
-$strRunSQLQuery = 'ǡ١%sפ SQL ¹Ԥ';
-$strRunSQLQueryOnServer = 'С%sפ SQL ¹Ԥ';
+$strRunSQLQuery = 'ǡ١%s SQL ¹Ԥ';
+$strRunSQLQueryOnServer = 'С%s SQL ¹Ԥ';
 $strRussian = '';
 
 $strSave = '¸';
-$strSaveOnServer = 'СΥǥ쥯ȥ%sפ¸';
+$strSaveOnServer = 'оΥǥ쥯ȥ%s¸';
 $strScaleFactorSmall = '1 ڡ˿ɽ֤뤿ˤ礭᤮ޤ';
+$strSearch = '';
 $strSearchFormTitle = 'ǡ١򸡺';
 $strSearchInTables = 'ơ֥λ:';
 $strSearchNeedle = 'ñ졢ޤ (磻ɥɤ: "%"):';
@@ -672,7 +692,6 @@ $strSearchOption3 = 'Τʥե졼';
 $strSearchOption4 = 'ɽ';
 $strSearchResultsFor = ' "<i>%s</i>" %s:';
 $strSearchType = ':';
-$strSearch = '';
 $strSecretRequired = 'եϺ̩ѥե졼ɬפȤޤ(blowfish_secret)';
 $strSelectADb = 'ǡ١򤷤Ƥ';
 $strSelectAll = '';
@@ -682,19 +701,19 @@ $strSelectNumRows = 'Ȳ';
 $strSelectTables = 'ơ֥';
 $strSend = 'ե¸';
 $strSent = '';
-$strServerChoice = 'С򤹤';
-$strServerNotResponding = 'Сȿޤ';
-$strServer = 'С';
-$strServerStatusDelayedInserts = 'ٱ䥤󥵡';
+$strServer = '';
+$strServerChoice = 'Ф򤹤';
+$strServerNotResponding = 'Фȿޤ';
+$strServers = '';
 $strServerStatus = '󥿥';
-$strServerStatusUptime = ' MySQL С %s ưǡ%s ˵ưƤޤ';
-$strServerTabProcesslist = 'ץ';
+$strServerStatusDelayedInserts = 'ٱ䥤󥵡';
+$strServerStatusUptime = ' MySQL Ф %s ưǡ%s ˵ưƤޤ';
 $strServerTabVariables = 'ѿ';
-$strServerTrafficNotes = '<b>Сȥեå</b>: Υơ֥ MySQL СưƤΥͥåȥȥեåפɽޤ';
-$strServerVars = 'Сѿ';
-$strServerVersion = 'СΥС';
+$strServerTrafficNotes = '<b>Хȥեå</b>: Υơ֥ MySQL ФưƤΥͥåȥȥեåפɽޤ';
+$strServerVars = 'ѿ';
+$strServerVersion = 'ФΥС';
 $strSessionValue = 'å';
-$strSetEnumVal = 'եɥפenumϡsetפξͤˤν񼰤ȤäϤƤ: \'a\',\'b\',\'c\'...<br />Хåå"\"ϥȡ"\'"פϤȡƬ˥ХååդƲ(: \\\\xyzפ⤷ϡa\\\'b)';
+$strSetEnumVal = 'եɥפenumϡsetξͤˤν񼰤ȤäϤƤ: \'a\',\'b\',\'c\'...<br />Хåå"\"ϥȡ"\'"ϤȡƬ˥ХååդƲ(: \\\\xyz⤷ϡa\\\'b)';
 $strShowAll = '٤ɽ';
 $strShowColor = 'ɽ';
 $strShowDatadictAs = 'ǡ';
@@ -709,17 +728,17 @@ $strShowSlaveHosts = '졼֥ۥȤɽ';
 $strShowSlaveStatus = '졼֤ξ֤ɽ';
 $strShowStatusBinlog_cache_disk_useDescr = 'ƥݥХʥåѤ褦Ȥơbinlog_cache_sizeͤĶᤷᡢȥ󥶥ΥơȥȤƥݥե¸ȥ󥶥ο';
 $strShowStatusBinlog_cache_useDescr = 'ХʥåѤοǤ';
-$strShowStatusCreated_tmp_disk_tablesDescr = 'ʸ¹˥СˤäƼưŪ˥ǥ˺줿ơ֥οǤCreated_tmp_disk_tables 礭硢ΰơ֥ǥ١Ѥ˥١ˤ褦ˡ tmp_table_size 䤷Ǥ礦';
+$strShowStatusCreated_tmp_disk_tablesDescr = 'ʸ¹˥ФˤäƼưŪ˥ǥ˺줿ơ֥οǤCreated_tmp_disk_tables 礭硢ΰơ֥ǥ١Ѥ˥١ˤ褦ˡ tmp_table_size 䤷Ǥ礦';
 $strShowStatusCreated_tmp_filesDescr = 'mysqld ϤɤΰŪեǤ';
-$strShowStatusCreated_tmp_tablesDescr = 'Сǹʸμ¹ԤˤäƼưŪ˺줿ΰơ֥ο';
+$strShowStatusCreated_tmp_tablesDescr = 'Фǹʸμ¹ԤˤäƼưŪ˺줿ΰơ֥ο';
 $strShowStatusDelayed_errorsDescr = '㴳Υ顼ȯ INSERT DELAYED 񤫤줿ԿǤ (餯νʣ)';
 $strShowStatusDelayed_insert_threadsDescr = ' INSERT DELAYED ϥɥ顼åɤοINSERT DELAYED ŬѤۤʤơ֥οͭΥåɤѰդޤ';
 $strShowStatusDelayed_writesDescr = 'INSERT DELAYED 񤭹ߤ򤷤Ǥ';
 $strShowStatusFlush_commandsDescr  = 'FLUSH ʸ¹ԤǤ';
 $strShowStatusHandler_commitDescr = 'COMMIT ʸǤ';
 $strShowStatusHandler_deleteDescr = 'ơ֥뤫Ǥ';
-$strShowStatusHandler_discoverDescr = 'MySQLФNDB饹ȥ졼󥸥̾ĥơ֥ˤĤƤξäƤ뤫䤤碌뤳ȤǤޤϳȸƤФƤޤHandler_discoverϡ줿ơ֥ο򼨤ޤ';
-$strShowStatusHandler_read_firstDescr = 'ǥåϤΥȥɤ߹Ǥ줬⤤硢ϥС¿δʥǥåԤäƤȼޤ㤨СSELECT col1 FROM fooפ col1 ϥǥåȲꤷޤ';
+$strShowStatusHandler_discoverDescr = 'MySQLФNDB饹ȥ졼󥸥ĥơ֥ˤĤƤξäƤ뤫䤤碌뤳ȤǤޤϳȸƤФƤޤHandler_discoverϡ줿ơ֥ο򼨤ޤ';
+$strShowStatusHandler_read_firstDescr = 'ǥåϤΥȥɤ߹Ǥ줬⤤硢ϥФ¿δʥǥåԤäƤȼޤ㤨СSELECT col1 FROM foo col1 ϥǥåȲꤷޤ';
 $strShowStatusHandler_read_keyDescr = '˴ŤƹԤɤ߹׵οǤ줬⤤硢ϤʤξȲȥơ֥뤬Ŭڤ˥ǥåդƤȤ褤ɽǤ';
 $strShowStatusHandler_read_nextDescr = 'ν̤˹ԤɤǤꥯȤοͤϰϤĤƥǥåȲ񤷤Ƥ뤫ǥåԤäƤȤޤ';
 $strShowStatusHandler_read_prevDescr = 'ν̤˹Ԥ̤äɤǤꥯȤοɤ߹ߤϼORDER BY ... DESCŬȤѤޤ';
@@ -794,14 +813,14 @@ $strShowStatusQcache_queries_in_cacheDescr = 'åϿ줿ȲοǤ';
 $strShowStatusQcache_total_blocksDescr = 'Ȳ񥭥å֥åǤ';
 $strShowStatusReset = 'ꥻå';
 $strShowStatusRpl_statusDescr = 'ե륻եץꥱξ֤Ǥ (Ƥޤ)';
-$strShowStatusSelect_full_joinDescr = 'ǥåѤʤοǤͤ 0 Ǥʤ硢տơ֥Υǥåǧ٤Ǥ';
+$strShowStatusSelect_full_joinDescr = 'ǥåѤʤοǤͤ 0 Ǥʤ硢ơ֥Υǥå褯ǧƤ';
 $strShowStatusSelect_full_range_joinDescr = 'Ϣơ֥ϰϸѤοǤ';
 $strShowStatusSelect_range_checkDescr = 'ʤjoinϳƹԤˤĤƥλ٤åΤǤʤ줬0ʳξϥơ֥Υǥå褯åƤˡ';
 $strShowStatusSelect_rangeDescr = 'ǽΥơ֥ϰϤѤοǤ (줬礭Ƥ̾ϴǤϤޤ)';
 $strShowStatusSelect_scanDescr = 'ǽΥơ֥δʥԤäοǤ';
 $strShowStatusSlave_open_temp_tablesDescr = '졼 SQL åɤˤäƸ߳ƤŪơ֥οǤ';
 $strShowStatusSlave_retried_transactionsDescr = 'ץꥱΥ졼 SQL åɤȥ󥶥ƻԤ(ư)׿';
-$strShowStatusSlave_runningDescr = 'ΥСޥ³륹졼֤Ǥ硢 ON Ǥ';
+$strShowStatusSlave_runningDescr = 'ΥФޥ³륹졼֤Ǥ硢 ON Ǥ';
 $strShowStatusSlow_launch_threadsDescr = 'slow_launch_time ÿ֤äƺ줿åɤοǤ';
 $strShowStatusSlow_queriesDescr = 'long_query_time ÿۤȲοǤ';
 $strShowStatusSort_merge_passesDescr = 'ȥ르ꥺब¹ԤʤФʤʤäޡβͤ⤤ϡsort_buffer_sizeƥѿͤ䤹ȤƤƤ';
@@ -810,7 +829,7 @@ $strShowStatusSort_rowsDescr = 'ȺѤιԿǤ';
 $strShowStatusSort_scanDescr = 'ơ֥ˤԤ줿ȿǤ';
 $strShowStatusTable_locks_immediateDescr = 'ơ֥å˼줿Ǥ';
 $strShowStatusTable_locks_waitedDescr = 'ơ֥å˼Ǥʤä˥Ȥȯͤ⤯ѥեޥ󥹤꤬ƤϡޤȲŬƤǤʤ顢ơ֥ʬ䤹뤫ץꥱѤƤ';
-$strShowStatusThreads_cachedDescr = 'åɥåΥåɿǤåҥåΨ Threads_created/Connections ȤƷ׻뤳ȤǤޤ֤ͤ硢thread_cache_size 夲٤Ǥ';
+$strShowStatusThreads_cachedDescr = 'åɥåΥåɿǤåҥåΨ Threads_created/Connections ȤƷ׻뤳ȤǤޤֻͤˤʤäƤȤ thread_cache_size 夲Ƥ';
 $strShowStatusThreads_connectedDescr = '³οǤ';
 $strShowStatusThreads_createdDescr = '³򰷤˺줿åɤοǤThreads_created 礭硢 thread_cache_size äȻפ⤷ޤ(̾褤åɼ򤷤Ƥ硢ϸʥѥեޥ󥹸Ϳޤ)';
 $strShowStatusThreads_runningDescr = '꡼פƤʤåɤοǤ';
@@ -823,19 +842,19 @@ $strSize = '';
 $strSkipQueries = 'Ϥ饹åפ쥳(Ȳ)ο';
 $strSlovak = 'Х';
 $strSlovenian = '٥˥';
-$strSocketProblem = '(ޤϡ MySQL СΥåȤΤꤵޤ)';
+$strSocketProblem = '(ޤϡ MySQL ФΥåȤΤꤵޤ)';
+$strSort = '';
 $strSortByKey = 'ǥ';
 $strSorting = '';
-$strSort = '';
 $strSpaceUsage = 'ǥ';
 $strSpanish = 'ڥ';
 $strSplitWordsWithSpace = 'ñϥڡʸ(" ")ǶڤäƲ';
-$strSQLExportCompatibility = 'SQL ߴݡ';
+$strSQLCompatibility = 'SQLߴ⡼';
 $strSQLExportType = 'ݡȷ';
 $strSQLImportOptions = 'SQL ץ';
 $strSQLOptions = 'SQL ץ';
-$strSQLParserBugMessage = 'ʤ SQL ѡΥХ򸫤뤫⤷ޤ󡣤ʤ䤤碌ǰ˳Τơ䤬ߥޥåʤåޤ礦¾μԤˤϥƥȥꥢǰѤ¦˥Хʥ꡼ɤդƥե뤬åץɤƤޤä褦ʸͤޤޤʤ䤤碌 MySQL Υޥɥ饤ȤäƻȤǤޤMySQL СϰʲΤ褦˥顼Фޤˤ褹Ǥ礦ޥɥ饤ǤƤ⡢ޤ꤬硢ѡԤˤϡΤ SQL 䤤碌ҤȤĤʸ˸餷ƤߤƲưʲΥǥǡڤäƥХäƲ:';
-$strSQLParserUserError = 'SQL ˥顼ޤMySQL СϰʲΤ褦˥顼Ϥޤˤ褹Ǥ礦';
+$strSQLParserBugMessage = 'ʤ SQL ѡΥХ򸫤뤫⤷ޤ󡣤ʤ䤤碌ǰ˳Τơ䤬ߥޥåʤåޤ礦¾μԤˤϥƥȥꥢǰѤ¦˥Хʥ꡼ɤդƥե뤬åץɤƤޤä褦ʸͤޤޤʤ䤤碌 MySQL Υޥɥ饤ȤäƻȤǤޤMySQL ФϰʲΤ褦˥顼Фޤˤ褹Ǥ礦ޥɥ饤ǤƤ⡢ޤ꤬硢ѡԤˤϡΤ SQL 䤤碌ҤȤĤʸ˸餷ƤߤƲưʲΥǥǡڤäƥХäƲ:';
+$strSQLParserUserError = 'SQL ˥顼ޤMySQL ФϰʲΤ褦˥顼Ϥޤˤ褹Ǥ礦';
 $strSQLQuery = '¹Ԥ SQL';
 $strSQLResult = 'SQL η';
 $strSQL = 'SQL';
@@ -845,16 +864,16 @@ $strSQPBugUnknownPunctuation = '̵ʶʸǤ';
 $strStatCheckTime = 'ǽ';
 $strStatCreateTime = '';
 $strStatement = 'ơȥ';
-$strStatisticsOverrun = 'ӥʥСǤϡХȥ󥿡Ķ᤹뤫⤷ޤ󡣽äơMySQL С𤹤뤽פʤ⤷ޤ';
+$strStatisticsOverrun = 'ӥʥФǤϡХȥ󥿤Ķ᤹뤫⤷ޤ󡣽äơMySQL Ф𤹤뤽פʤ⤷ޤ';
 $strStatUpdateTime = 'ǽ';
 $strStatus = '';
 $strStorageEngine = 'ȥ졼󥸥';
 $strStorageEngines = 'ȥ졼󥸥';
 $strStrucCSV = 'CSV ǡ';
 $strStrucData = '¤ȥǡ';
-$strStrucDrop = 'DROP TABLEפɲä';
 $strStrucExcelCSV = 'MS Excel  CSV ǡ';
 $strStrucNativeExcel = ' MS Excel ǡ';
+$strStrucNativeExcelOptions = 'ExcelΥͥƥ֥ݡȤΥץ';
 $strStrucOnly = '¤Τ';
 $strStructPropose = 'ơ֥빽¤ǧ';
 $strStructure = '¤';
@@ -868,7 +887,7 @@ $strSwitchToTable = 'ԡơ֥ڤؤ';
 $strTable = 'ơ֥ ';
 $strTableAlreadyExists = 'ơ֥ %s ϴ¸ߤޤ!';
 $strTableComments = 'ơ֥';
-$strTableEmpty = 'ơ֥̾϶Ǥ';
+$strTableEmpty = 'ơ֥϶Ǥ';
 $strTableHasBeenDropped = 'ơ֥ %s ޤ';
 $strTableHasBeenEmptied = 'ơ֥ %s ˤޤ';
 $strTableHasBeenFlushed = 'ơ֥ %s Υåˤޤ';
@@ -877,26 +896,25 @@ $strTableOfContents = 'ơ֥';
 $strTableOptions = 'ơ֥륪ץ';
 $strTables = '%sơ֥';
 $strTableStructure = 'ơ֥ι¤';
-$strTableType = 'ơ֥Υ';
 $strTakeIt = 'ˤޤ';
 $strTblPrivileges = 'ơ֥ ø';
 $strTempData = 'ǡ';
 $strTextAreaLength = ' Ĺν٤ǤΥեɤ<br /> Ǥʤǽޤ';
 $strThai = '';
 $strTheme = 'ơ / ';
-$strThemeDefaultNotFound = 'ǥեȥơޡ%sפĤޤ!';
+$strThemeDefaultNotFound = 'ǥեȥơޡ%sĤޤ!';
 $strThemeNoPreviewAvailable = 'ץӥ塼ѤǤޤ';
-$strThemeNotFound = 'ơޡ%sפĤޤ!';
-$strThemeNoValidImgPath = 'ơޡ%sפѥĤޤ!';
-$strThemePathNotFound = 'ơޡ%sפΥơޥѥĤޤ!';
+$strThemeNotFound = 'ơޡ%sĤޤ!';
+$strThemeNoValidImgPath = 'ơޡ%sѥĤޤ!';
+$strThemePathNotFound = 'ơޡ%sΥơޥѥĤޤ!';
 $strThisHost = 'Υۥ';
 $strThisNotDirectory = 'ϥǥ쥯ȥǤϤޤ';
 $strThreads = 'å';
 $strThreadSuccessfullyKilled = 'å %s Ͻλޤ';
+$strTime = '';
 $strTimeoutInfo = '˥ݡȤǥॢȤƤޤ塢 %d ³Ǥ礦';
 $strTimeoutNothingParsed = 'Ǹμ¹ԤǤΥǡϲϤƤޤ󡣤ϡ̾ php λ¤䤵ʤ phpMyAdmin ΥݡȤλ뤳ȤǤʤȤȤ̣ޤ';
 $strTimeoutPassed = 'ץȤॢȤ᤮ޤݡȤ򽪤餻硢ƱեݡȤƳƤ';
-$strTime = '';
 $strToggleScratchboard = 'ȥ륹åܡ';
 $strTotal = '';
 $strTotalUC = '';
@@ -904,18 +922,18 @@ $strTraditionalChinese = 'Ū';
 $strTraditionalSpanish = 'Ūʥڥ';
 $strTraffic = 'ȥեå';
 $strTransactionCoordinator = 'ȥ󥶥󥳡ǥ͡';
-$strTransformation_application_octetstream__download = 'եɤΥХʥǡɤ󥯤ɽޤ1 ܤΥץϥХʥեΥե̾Ǥ2 ܥץϥե̾ޤơ֥Ԥե̾Ǥ2 ܤΥץ󶡤硢1 ܤΥץ϶ʸꤹɬפޤ';
+$strTransformation_application_octetstream__download = 'եɤΥХʥǡɤ󥯤ɽޤ1 ܤΥץϥХʥեΥեǤ2 ܥץϥեޤơ֥ԤեɤǤ2 ܤΥץ󶡤硢1 ܤΥץ϶ʸꤹɬפޤ';
 $strTransformation_application_octetstream__hex = 'ǡ 16 ʿɽǤ';
 $strTransformation_image_jpeg__inline = 'åǽʥͥɽޤ; ץ: widthheight ԥǻ (Ψݤޤ)';
 $strTransformation_image_jpeg__link = 'βؤΥ󥯤ɽ (㤨 blob ľܥ).';
-$strTransformation_image_png__inline = 'image/jpeg: inlineפ򻲾ȤƤ';
+$strTransformation_image_png__inline = 'image/jpeg: inline򻲾ȤƤ';
 $strTransformation_text_plain__dateformat = 'TIMETIMESTAMP 뤤 DATETIME եɤǡɽѤƽ񼰲ޤ1 ܤΥץϥॹפ˲û륪եåȻ(ñ:)Ǥ(ǥե: 0)2 ܤΥץϡPHP  strftime()Ѳǽʥѥ᡼ǤΤޤޤɽǤ';
-$strTransformation_text_plain__external = 'LINUX Τ: ץꥱưɸϤեɥǡϤޤץꥱɸϤ֤ޤǥեȤ Tidy ǡ HTML ɤϤޤƥͳǡưǥեlibraries/text_plain__external.inc.phpפԽ¹ԤĤġʤФʤޤ󡣺ǽΥץϡѤץοǡ2 ܤΥץϥץΥѥ᡼Ǥ3 ܤΥץ 1 ꤵƤ硢htmlspecialchars() ѤƽϤѴǤ礦(ǥե: 1)4  ץ 1 ꤵƤ硢§ɤϤ٤ 1 Ԥ˸뤳ȤݾڤǤ礦(ǥե: 1).';
+$strTransformation_text_plain__external = 'LINUX Τ: ץꥱưɸϤեɥǡϤޤץꥱɸϤ֤ޤǥեȤ Tidy ǡ HTML ɤϤޤƥͳǡưǥեlibraries/text_plain__external.inc.phpԽ¹ԤĤġʤФʤޤ󡣺ǽΥץϡѤץοǡ2 ܤΥץϥץΥѥ᡼Ǥ3 ܤΥץ 1 ꤵƤ硢htmlspecialchars() ѤƽϤѴǤ礦(ǥե: 1)4  ץ 1 ꤵƤ硢§ɤϤ٤ 1 Ԥ˸뤳ȤݾڤǤ礦(ǥե: 1).';
 $strTransformation_text_plain__formatted = 'եɤθν񼰤¸ޤפ˽λޤ';
-$strTransformation_text_plain__imagelink = 'ȥ󥯡ե̾ޤեɤɽޤ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭǡ2 ܤΥץϥԥ3 ܤϹ⤵Ǥ';
-$strTransformation_text_plain__link = 'ե̾ޤեɡ󥯤ɽ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭ졢2 ܤΥץϥ󥯤ΥȥǤ';
+$strTransformation_text_plain__imagelink = 'ȥ󥯡եޤեɤɽޤ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭǡ2 ܤΥץϥԥ3 ܤϹ⤵Ǥ';
+$strTransformation_text_plain__link = 'եޤեɡ󥯤ɽ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭ졢2 ܤΥץϥ󥯤ΥȥǤ';
 $strTransformation_text_plain__sql = 'SQL Ҳ ȤƥƥȤηʸˡϥ饤Ȥޤ';
-$strTransformation_text_plain__substr = 'ʸΰΤɽޤ1 ܤΥץϥƥȤνϤɤǳϤ뤫եåȤޤ (ǥեȤϡ0פǤ)2 ܤΥץϤɤΥƥȤ֤ΥեåȤǤξ硢ĤΥƥȤ򤹤٤֤ޤ3 ܤΥץϡʸΰ֤ɤʸϤɲä뤫ޤ (ǥեȤϡ...פǤ)';
+$strTransformation_text_plain__substr = 'ʸΰΤɽޤ1 ܤΥץϥƥȤνϤɤǳϤ뤫եåȤޤ (ǥեȤϡ0Ǥ)2 ܤΥץϤɤΥƥȤ֤ΥեåȤǤξ硢ĤΥƥȤ򤹤٤֤ޤ3 ܤΥץϡʸΰ֤ɤʸϤɲä뤫ޤ (ǥեȤϡ...Ǥ)';
 $strTruncateQueries = 'Ȳɽڤͤ';
 $strTurkish = 'ȥ륳';
 $strType = 'եɥ';
@@ -931,16 +949,17 @@ $strUpdatePrivMessage = '%s ø򹹿ޤ';
 $strUpdateProfileMessage = 'ץե򹹿ޤ';
 $strUpdateQuery = 'Ȳ򹹿';
 $strUpdComTab = 'Column_comments ơ֥Υåץ졼ˡΥɥȤ򻲾ȤƤ';
-$strUpgrade = '%s %s ܹԤ˥åץ졼ɤ٤Ǥ';
+$strUpgrade = '%s %s ʹߤ˥åץ졼ɤƤ';
 $strUploadLimit = '餯ޤˤ礭ʥե򥢥åץɤ褦Ȥޤ¤βʤȤ %sɥ%s 򻲾ȤƤ';
+$strUploadsNotAllowed = 'ΥФǤϥեΥåץɤؤƤޤ';
 $strUsage = '';
-$strUseBackquotes = 'եȤǥơ֥̾ե̾Ϥ';
+$strUseBackquotes = 'եȤǥơ֥եɤϤ';
 $strUsedPhpExtensions = ' PHP ĥ';
 $strUseHostTable = 'ۥȥơ֥Ȥ';
+$strUserAlreadyExists = '桼%sϴ¸ߤޤ!';
 $strUser = '桼';
-$strUserAlreadyExists = '桼%sפϴ¸ߤޤ!';
-$strUserEmpty = '桼̾϶Ǥ';
-$strUserName = '桼̾';
+$strUserEmpty = '桼϶Ǥ';
+$strUserName = '桼';
 $strUserNotFound = '򤵤줿桼øơ֥˸ĤޤǤ';
 $strUserOverview = '桼ά';
 $strUsersDeleted = '򤵤줿桼Ϻޤ';
@@ -955,15 +974,15 @@ $strValidatorError = 'SQL θڵǽǤޤ%sɥ%s ˵ҤƤ褦 PHP ĥ饤֥꤬󥹥ȡ뤵Ƥ
 $strValue = '';
 $strVar = 'ѿ';
 $strVersionInformation = 'С';
+$strView = 'ӥ塼';
 $strViewDump = 'ơ֥Υ()ɽ';
 $strViewDumpDatabases = 'ǡ١Υץӥ塼 ()';
 $strViewDumpDB = 'DB Υ()ɽ';
 $strViewHasBeenDropped = 'ӥ塼 %s ˴ޤ';
 $strViewMaxExactCount = 'Υӥ塼 %s ʾ夢ޤ%sɥ%s 򻲾ȤƤ';
-$strView = 'ӥ塼';
 
+$strWebServerUploadDirectory = '֥оǥåץɤ';
 $strWebServerUploadDirectoryError = 'åץɤԤǥ쥯ȥ꤬ޤ';
-$strWebServerUploadDirectory = '֥Сǥåץɤ';
 $strWelcome = '%s ؤ褦';
 $strWestEuropean = '衼åѸ';
 $strWildcard = '磻ɥ';
@@ -972,9 +991,10 @@ $strWithChecked = 'åΤ:';
 $strWriteRequests = '񤭹ߥꥯȿ';
 $strWritingCommentNotPossible = 'Ȥν񤭹ߤͭǤϤޤ';
 $strWritingRelationNotPossible = '졼ν񤭹ߤͭǤϤޤ';
-$strWrongUser = '桼̾ޤϥѥɤޤ<br />ϵݤޤ';
+$strWrongUser = '桼ޤϥѥɤޤ<br />ϵݤޤ';
 
 $strXkana = 'ѥʤѴ'; // convert to X208-kana
+$strXMLOptions = 'XMLץ';
 $strXML = 'XML';
 
 $strYes = 'Ϥ';
