@@ -1,13 +1,12 @@
 <?php
-/* $Id: slovak-windows-1250.inc.php,v 2.123.2.3 2006/03/23 17:42:15 lem9 Exp $ */
+/* $Id: slovak-windows-1250.inc.php,v 2.150 2006/08/09 12:55:40 lem9 Exp $ */
 
 /* By: lubos klokner <erkac@vault-tec.sk> */
-/* and Ivan Kuriscak <shylauda69@yahoo.com> */
+/* and Ivan Kuriscak <shylauda69@yahoo.com>
+   and Tomas Tatransky <tomas.tatransky@centrum.sk> */
 
 $charset = 'windows-1250';
 $text_dir = 'ltr';
-$left_font_family = '"verdana ce", "arial ce", verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'tahoma, "verdana ce", "arial ce", helvetica, arial, geneva, sans-serif';
 $number_thousands_separator = ' ';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
@@ -22,24 +21,24 @@ $timespanfmt = '%s dn, %s hodn, %s mint a %s seknd';
 
 $strAbortedClients = 'Preruen';
 $strAbsolutePathToDocSqlDir = 'Prosm zadajte absoltnu cestu k adresru docSQL na serveri.';
+$strAccessDeniedCreateConfig = 'Pravdepodobn prina je, e neexistuje konfiguran sbor. Na jeho vytvorenie mete poui %1$skonfiguran skript%2$s.';
 $strAccessDeniedExplanation = 'phpMyAdmin sa poksil pripoji k MySQL serveru ale ten spojenie odmietol. Skontrolujte prosm meno serveru, pouvatesk meno a heslo v sbore config.inc.php a s tm, ktor ste dostali o administrtora MySQL servera.';
 $strAccessDenied = 'Prstup zamietnut';
 $strAction = 'Akcia';
 $strAddAutoIncrement = 'Prida hodnotu AUTO_INCREMENT';
+$strAddClause = 'Prida %s';
 $strAddConstraints = 'Prida obmedzenia';
 $strAddDeleteColumn = 'Prida/Odobra polia stpcov';
 $strAddDeleteRow = 'Prida/Odobra kritria riadku';
-$strAddDropDatabase = 'Prida DROP DATABASE';
 $strAddedColumnComment = 'Pridan komentr k stpcu';
 $strAddedColumnRelation = 'Pridan vzah pre stpec';
 $strAddFields = 'Prida %s poloiek';
 $strAddHeaderComment = 'Prida vlastn komentr do hlaviky (\\n oddeuje riadky)';
-$strAddIfNotExists = 'Prida IF NOT EXISTS';
 $strAddIntoComments = 'Prida do komentrov';
 $strAddNewField = 'Prida nov pole';
 $strAddPrivilegesOnDb = 'Prida oprvnenia pre nasledujcu databzu';
 $strAddPrivilegesOnTbl = 'Prida oprvnenia pre nasledujcu tabuku';
-$strAddSearchConditions = 'Prida vyhadvacie parametre (obsah dotazu po "where" prkaze):';
+$strAddSearchConditions = 'Prida vyhadvacie parametre (obsah dopytu po "where" prkaze):';
 $strAddToIndex = 'Prida do indexu &nbsp;%s&nbsp;stpec';
 $strAddUserMessage = 'Pouvate bol pridan.';
 $strAddUser = 'Prida novho pouvatea';
@@ -89,10 +88,11 @@ $strBookmarkAllUsers = 'Dovoli pouva tto poloku vetkm pouvateom';
 $strBookmarkCreated = 'Prkaz %s bol zaraden medzi obben';
 $strBookmarkDeleted = 'Zznam z obbench bol zmazan.';
 $strBookmarkLabel = 'Nzov';
-$strBookmarkQuery = 'Obben SQL dotaz';
+$strBookmarkQuery = 'Obben SQL dopyt';
 $strBookmarkReplace = 'Prepsa existujci prkaz s rovnakm menom';
-$strBookmarkThis = 'Prida tento SQL dotaz do obbench';
+$strBookmarkThis = 'Prida tento SQL dopyt do obbench';
 $strBookmarkView = 'Iba prezrie';
+$strBrowseDistinctValues = 'Prechdza in hodnoty';
 $strBrowseForeignValues = 'Prejs hodnoty cudzch kov';
 $strBrowse = 'Prechdza';
 $strBufferPoolActivity = 'Aktivita Vyrovnvacej Pamte';
@@ -108,12 +108,13 @@ $strBzError = 'nepodarilo sa skomprimova vstup z dvodu chybnho rozrenia pre komp
 $strBzip = '"bzipped"';
 
 $strCalendar = 'Kalendr';
+$strCanNotLoadExportPlugins = 'Nepodarilo sa nata exportn pluginy, skontrolujte prosm vau intalciu!';
 $strCanNotLoadImportPlugins = 'Nebolo mon nata importovacie pluginy, skontrolujte prosm vau intalciu!';
 $strCannotLogin = 'Ned sa prihlsi k MySQL serveru';
 $strCantLoad = 'ned sa nahra rozrenie %s,<br />prosm skontrolujte konfigurciu PHP';
 $strCantLoadRecodeIconv = 'Nie je mon nahra rozrenie iconv alebo recode potrebn pre prevod znakovch sad. Upravte nastavenie php tak aby umoovalo poui tieto rozrenia alebo vypnite tto vlastnos v konfigurcii phpMyAdmina.';
 $strCantRenameIdxToPrimary = 'Nie je mon premenova index na PRIMARY!';
-$strCantUseRecodeIconv = 'Nie je mon poui funkcie iconv,libiconv a recode_string aj napriek tomu, e rozrenia s nahran. Skontrolujte prosm nastavenie PHP.';
+$strCantUseRecodeIconv = 'Nie je mon poui funkcie iconv, libiconv a recode_string aj napriek tomu, e rozrenia s nahran. Skontrolujte prosm nastavenie PHP.';
 $strCardinality = 'Mohutnos';
 $strCaseInsensitive = 'nerozliova vek a mal psmen';
 $strCaseSensitive = 'rozliova vek a mal psmen';
@@ -128,7 +129,7 @@ $strChangeDisplay = 'Zvolte, ktor pole zobrazi';
 $strChangePassword = 'Zmeni heslo';
 $strChange = 'Zmeni';
 $strCharsetOfFile = 'Znakov sada sboru:';
-$strCharsetsAndCollations = 'Znakov sady a porovnvanie';
+$strCharsetsAndCollations = 'Znakov sady a Zotriedenia';
 $strCharsets = 'Znakov sady';
 $strCharset = 'Znakov sada';
 $strCheckAll = 'Oznai vetko';
@@ -138,7 +139,7 @@ $strCheckPrivs = 'Skontrolova oprvnenia';
 $strCheckTable = 'Skontrolova tabuku';
 $strChoosePage = 'Prosm zvolte si Strnku, ktor chcete upravi';
 $strColComFeat = 'Zobrazova komentre stpcov';
-$strCollation = 'Porovnvanie';
+$strCollation = 'Zotriedenie';
 $strColumnNames = 'Nzvy stpcov';
 $strColumnPrivileges = 'Oprvnenia pre jednotliv stpce';
 $strCommand = 'Prkaz';
@@ -148,6 +149,7 @@ $strCompatibleHashing = 'Kompatibiln s&nbsp;MySQL&nbsp;4.0';
 $strCompleteInserts = 'pln vloenie';
 $strCompression = 'Kompresia';
 $strCompressionWillBeDetected = 'Kompresia importovanho sboru bude rozpoznan automaticky. Podporovan: %s';
+$strConfigDefaultFileError = 'Nepodarilo sa nata prednastaven konfigurciu zo sboru: "%1$s"';
 $strConfigFileError = 'phpMyAdmin nebol schopn nata konfiguran sbor!<br />Tento problm sa zvyajne vyskytne ak sbor obsahuje chybu alebo ho php nemohlo njs.<br />Zavolajte browserom tento sbor priamo pouitm nasledujceho odkazu na zskanie chybovch hlok, ktor s nm spsoben. Vinou sa jedn o chbajcu vodzovku alebo bodkoiarku.<br />Ak dostanete iba przdnu strnku, vetko je v poriadku.';
 $strConfigureTableCoord = 'Prosm skonfigurujte koordinty pre tabuku %s';
 $strConnectionError = 'Nepodarilo sa pripoji: chybn nastavenia.';
@@ -168,13 +170,17 @@ $strCreateNewDatabase = 'Vytvori nov databzu';
 $strCreateNewTable = 'Vytvori nov tabuku v databze %s';
 $strCreatePage = 'Vytvori nov Strnku';
 $strCreatePdfFeat = 'Vytvranie PDF';
+$strCreateUserDatabase = 'Databza pre pouvatea';
+$strCreateUserDatabaseName = 'Vytvori databzu s rovnakm menom a prideli vetky oprvnenia';
+$strCreateUserDatabaseNone = 'iadna';
+$strCreateUserDatabaseWildcard = 'Prideli vetky oprvnenia pomocou masky (pouvate_%)';
 $strCreate = 'Vytvori';
 $strCreationDates = 'Dtum vytvorenia, poslednej zmeny a kontroly';
 $strCriteria = 'Kritria';
 $strCroatian = 'Chorvtsky';
 $strCSV = 'CSV';
 $strCSVImportOptions = 'Monosti CSV';
-$strCSVOptions = 'CSV nastavenia';
+$strCSVOptions = 'Nastavenia pre CSV';
 $strCyrillic = 'Cyrilika';
 $strCzech = 'esky';
 $strCzechSlovak = 'etina/Slovenina';
@@ -185,14 +191,14 @@ $strDatabaseEmpty = 'Meno databzy je przdne!';
 $strDatabaseExportOptions = 'Nastavenia exportu databz';
 $strDatabaseHasBeenDropped = 'Databza %s bola zmazan.';
 $strDatabaseNoTable = 'Tto databza neobsahuje iadne tabuky!';
-$strDatabases = 'databz(y)';
+$strDatabases = 'Databzy';
 $strDatabasesDropped = 'spene zruench databz: %s.';
 $strDatabasesStatsDisable = 'Skry tatistiky';
 $strDatabasesStatsEnable = 'Zobrazi tatistiky';
 $strDatabasesStatsHeavyTraffic = 'Poznmka: Aktivovanie tatistk databzy me spsobi znan zvenie sieovej prevdzky medzi databzou a web serverom.';
 $strDatabasesStats = 'tatistiky databzy';
-$strDataDict = 'Dtov slovnk';
 $strData = 'Dta';
+$strDataDict = 'Dtov slovnk';
 $strDataOnly = 'Iba dta';
 $strDataPages = 'Strnky obsahujce dta';
 $strDBComment = 'Komentr k databze: ';
@@ -218,9 +224,10 @@ $strDeleteAndFlushDescr = 'Toto je najistejie rieenie, ale znovunatanie prv me c
 $strDeleteAndFlush = 'Odstrni pouvateov a znovunata prva.';
 $strDeleted = 'Riadok bol zmazan';
 $strDeletedRows = 'Zmazan riadky:';
-$strDeleteNoUsersSelected = 'Na odstrnenie neboli vybran iadni uvatelia!';
+$strDeleteNoUsersSelected = 'Na odstrnenie neboli vybran iadni pouvatelia!';
 $strDelete = 'Zmaza';
 $strDeleting = 'Odstrauje sa %s';
+$strDelimiter = 'Oddeova';
 $strDelOld = 'Aktulna strnka sa odkazuje na tabuky, ktor u neexistuj, elte si odstrni tieto odkazy?';
 $strDescending = 'Zostupne';
 $strDescription = 'Popis';
@@ -231,7 +238,7 @@ $strDisableForeignChecks = 'Vypn kontrolu cudzch kov';
 $strDisplayFeat = 'Zobrazi vlastnosti';
 $strDisplayOrder = 'Zobrazi zoraden:';
 $strDisplayPDF = 'Zobrazi schmu PDF';
-$strDoAQuery = 'Vykona "dotaz poda prkladu" (nahradzujci znak: "%")';
+$strDoAQuery = 'Vykona "dopyt poda prkladu" (nahradzujci znak: "%")';
 $strDocu = 'Dokumentcia';
 $strDoYouReally = 'Skutone chcete vykona prkaz ';
 $strDropDatabaseStrongWarning = 'Chystte sa ZRUI cel databzu!';
@@ -261,14 +268,16 @@ $strEnglish = 'Anglicky';
 $strEnglishPrivileges = ' Poznmka: nzvy MySQL oprvnen s uvdzan v anglitine. ';
 $strError = 'Chyba';
 $strErrorInZipFile = 'Chyba v ZIP archve:';
+$strErrorRenamingTable = 'Chyba pri premenovan tabuky %1$s na %2$s';
 $strEscapeWildcards = 'Nhradzujcim znakom _ a % by mal predchdza znak \, pokia ich nechcete poui doslovne';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estnsky';
 $strExcelEdition = 'Verzia Excelu';
-$strExcelOptions = 'Nastavenie exportu do Excelu';
-$strExecuteBookmarked = 'Spusti obben dotaz';
+$strExcelOptions = 'Nastavenia CSV pre Excel';
+$strExecuteBookmarked = 'Spusti obben dopyt';
 $strExplain = 'Vysvetli SQL';
 $strExport = 'Exportova';
+$strExportMustBeFile = 'Vybran typ exportu mus by uloen do sboru!';
 $strExtendedInserts = 'Rozren vkladanie';
 $strExtra = 'Extra';
 
@@ -282,6 +291,10 @@ $strFields = 'Polia';
 $strFieldsTerminatedBy = 'Polia ukonen';
 $strFileAlreadyExists = 'Sbor %s u existuje na servery, zmente nzov sboru alebo zvolte prepsanie sboru.';
 $strFileCouldNotBeRead = 'Sbor sa ned preta';
+$strFileNameTemplateDescriptionDatabase = 'meno databzy';
+$strFileNameTemplateDescriptionServer = 'meno servera';
+$strFileNameTemplateDescriptionTable = 'meno tabuky';
+$strFileNameTemplateDescription = 'Tto hodnota je interpretovan pomocou %1$sstrftime%2$s, take mete poui reazec pre formtovanie dtumu a asu. Naviac bud vykonan tieto nahradenia: %3$s. Ostatn text bude zachovan.';
 $strFileNameTemplateRemember = 'zapamta si vzor';
 $strFileNameTemplate = 'Vzor pre nzov sboru';
 $strFileToImport = 'Sbor na importovanie';
@@ -295,6 +308,7 @@ $strFormEmpty = 'Chbajca poloka vo formulri !';
 $strFreePages = 'Przdnych strnok';
 $strFullText = 'Pln texty';
 $strFunction = 'Funkcia';
+$strFunctions = 'Funkcie';
 
 $strGenBy = 'Vygenerovan';
 $strGeneralRelationFeat = 'Monosti veobecnch vzahov';
@@ -318,13 +332,13 @@ $strHaveToShow = 'Zvolte prosm aspo jeden stpec, ktor chcete zobrazi';
 $strHebrew = 'Hebrejsky';
 $strHexForBinary = 'Binrne pole vypisova v estnstkovej sstave';
 $strHome = 'Domov';
-$strHomepageOfficial = 'Oficilne strnky phpMyAdmin-a';
+$strHomepageOfficial = 'Oficilne strnky phpMyAdmin';
 $strHostEmpty = 'Nzov hostitea je przdny!';
 $strHost = 'Hostite';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Monosti exportu pre Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Nastavenia pre Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Monosti exportu pre Microsoft Word 2000';
+$strHTMLWordOptions = 'Nastavenia pre Microsoft Word 2000';
 $strHungarian = 'Maarsky';
 
 $strIcelandic = 'Islandina';
@@ -338,6 +352,7 @@ $strImportDocSQL = 'Importova sbory docSQL';
 $strImportFiles = 'Importova sbory';
 $strImportFormat = 'Formt importovanho sboru';
 $strImport = 'Import';
+$strImportSuccessfullyFinished = 'Import bol spene ukonen, bolo vykonanch %d dopytov.';
 $strIndexes = 'Indexy';
 $strIndexHasBeenDropped = 'Index pre %s bol odstrnen';
 $strIndex = 'Index';
@@ -360,7 +375,6 @@ $strInsecureMySQL = 'Konfiguran sbor obsahuje nastavenia (root bez hesla), ktor
 $strInsertAsNewRow = 'Vloi ako nov riadok';
 $strInsertedRowId = 'Id vloenho riadku:';
 $strInsertedRows = 'Vloen riadky:';
-$strInsertNewRow = 'Vloi nov riadok';
 $strInsert = 'Vloi';
 $strInternalNotNecessary = '* Vntorn vzah nie je nutn ak u vzah existuje v InnoDB.';
 $strInternalRelations = 'Intern vzahy';
@@ -368,10 +382,17 @@ $strInUse = 'prve sa pouva';
 $strInvalidAuthMethod = 'V konfigurcii je nastaven nesprvna autentifikan metda:';
 $strInvalidColumn = 'Bol zadan chybn stpec (%s)!';
 $strInvalidColumnCount = 'Poet stpcov mus by v ako nula.';
+$strInvalidCSVFieldCount = 'Chybn poet poloiek v CSV vstupe na riadku %d.';
+$strInvalidCSVFormat = 'Chybn formt v CSV vstupe na riadku %d.';
+$strInvalidCSVParameter = 'Chybn parameter pre CSV import: %s';
+$strInvalidDatabase = 'Chybn databza';
 $strInvalidFieldAddCount = 'Muste prida aspo jeden stpec.';
 $strInvalidFieldCount = 'Tabuka mus obsahova aspo jeden stpec.';
 $strInvalidLDIImport = 'Tento plug-in nepodporuje import komprimovanch sborov!';
 $strInvalidRowNumber = '%d nie je platn slo riadku.';
+$strInvalidServerHostname = 'Chybn nzov hostu pre server %1$s. Prosm, skontrolujte konfigurciu.';
+$strInvalidServerIndex = 'Chybn index serveru: "%s"';
+$strInvalidTableName = 'Chybn meno tabuky';
 
 $strJapanese = 'Japonina';
 $strJoins = 'Zjednotenia';
@@ -386,6 +407,8 @@ $strKill = 'Zabi';
 $strKorean = 'Krejina';
 
 $strLandscape = 'Na rku';
+$strLanguageFileNotFound = 'Jazykov sbor "%1$s" nebol njden.';
+$strLanguageUnknown = 'Neznmy jazyk: %1$s.';
 $strLatchedPages = 'Uzavretch strnok';
 $strLatexCaption = 'Nadpis tabuky';
 $strLatexContent = 'Obsah tabuky __TABLE__';
@@ -394,7 +417,7 @@ $strLatexContinued = '(pokraovanie)';
 $strLatexIncludeCaption = 'Zahrn nadpis tabuky';
 $strLatexLabel = 'Nvestie';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Nastavenia LaTeX';
+$strLaTeXOptions = 'Nastavenia pre LaTeX';
 $strLatexStructure = 'truktra tabuky __TABLE__';
 $strLatvian = 'Lotystina';
 $strLDI = 'CSV pomocou LOAD DATA';
@@ -452,6 +475,7 @@ $strMyISAMRepairThreads = 'Opravn vlkna';
 $strMyISAMSortBufferSizeDesc = 'Pam, ktor je alokovan pri zoraovan MyISAM indexov poas vykonvania prkazu REPAIR TABLE, alebo pri vytvran indexov prkazmi CREATE INDEX alebo ALTER TABLE.';
 $strMyISAMSortBufferSize = 'Vekos zoraovacej pamte';
 $strMySQLCharset = 'Znakov sada v MySQL';
+$strMysqlClientVersion = 'Verzia MySQL klienta';
 $strMySQLConnectionCollation = 'Overenie MySQL spojenia';
 $strMySQLSaid = 'MySQL hlsi: ';
 $strMySQLShowProcess = 'Zobrazi procesy';
@@ -461,8 +485,9 @@ $strMySQLShowVars = 'Zobrazi MySQL systmov premenn';
 $strName = 'Nzov';
 $strNext = 'al';
 $strNoActivity = 'Boli ste neaktvni viac ako %s seknd, prihlste sa prosm znovu';
-$strNoDatabases = 'iadne databzy';
 $strNoDatabasesSelected = 'Neboli vybran iadne databzy.';
+$strNoDatabases = 'iadne databzy';
+$strNoDataReceived = 'Neboli prijat iadne dta na import. Bu nebol natan iadny sbor alebo jeho vekos prekroila maximlnu vekos povolen v PHP. Pozri FAQ 1.16.';
 $strNoDescription = 'bez Popisu';
 $strNoDetailsForEngine = 'Pre tento lon systm nie s dostupn iadne podrobnejie informcie.';
 $strNoDropDatabases = 'Monos "DROP DATABASE" vypnut.';
@@ -484,7 +509,6 @@ $strNoRowsSelected = 'Nebol vybran iadny riadok';
 $strNoSpace = 'Nedostatok miesta pre uloenie sboru %s.';
 $strNoTablesFound = 'Neboli njden iadne tabuky v tejto datbaze.';
 $strNoThemeSupport = 'Zmena vzhadu nie je podporovan, skontrolujte si nastavenia a vzhady v adresri %s.';
-$strNothingToImport = 'Neboli zadan iadne dta na import!';
 $strNotNumber = 'Toto nie je slo!';
 $strNotOK = 'chyba';
 $strNotSet = 'Tabuka <b>%s</b> nebola njden alebo nie je nastaven v %s';
@@ -497,6 +521,11 @@ $strNumSearchResultsTotal = '<b>Celkovo:</b> <i>%s</i> vskyt(ov)';
 $strNumTables = 'Tabuky';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheetOptions = 'Nastavenia pre tabukov procesor Open Document';
+$strOpenDocumentSpreadsheet = 'Tabukov procesor Open Document';
+$strOpenDocumentText = 'Open Document Text';
+$strOpenDocumentTextOptions = 'Nastavenia pre Open Document Text';
+$strOpenNewWindow = 'Otvori nov okno phpMyAdmina';
 $strOperations = 'Opercie';
 $strOperator = 'Opertor';
 $strOptimizeTable = 'Optimalizova tabuku';
@@ -517,6 +546,9 @@ $strPasswordNotSame = 'Hesl sa nezhoduj!';
 $strPdfDbSchema = 'Schma databzy "%s"  - Strana %s';
 $strPdfInvalidTblName = 'Tabuka "%s" neexistuje!';
 $strPdfNoTables = 'iadne tabuky';
+$strPDFOptions = 'Nastavenia pre PDF';
+$strPDF = 'PDF';
+$strPDFReportTitle = 'Titulok vpisu';
 $strPerHour = 'za hodinu';
 $strPerMinute = 'za mintu';
 $strPerSecond = 'za sekundu';
@@ -545,8 +577,8 @@ $strPrivDescCreateDb = 'Povol vytvranie novch databz a tabuliek.';
 $strPrivDescCreateRoutine = 'Umouje vytvra uloen procedry.';
 $strPrivDescCreateTbl = 'Povol vytvranie novch tabuliek.';
 $strPrivDescCreateTmpTable = 'Povol vytvranie doasnch tabuliek.';
-$strPrivDescCreateUser = 'Umouje vytvra, odstraova a premenovva uvatesk kont.';
-$strPrivDescCreateView = 'Umouje vytvra nov nhady.';
+$strPrivDescCreateUser = 'Umouje vytvra, odstraova a premenovva pouvatesk kont.';
+$strPrivDescCreateView = 'Umouje vytvra nov pohady.';
 $strPrivDescDelete = 'Povol mazanie dt.';
 $strPrivDescDropDb = 'Povol odstraovanie databz a tabuliek.';
 $strPrivDescDropTbl = 'Povol odstraovanie tabuliek.';
@@ -558,11 +590,11 @@ $strPrivDescIndex = 'Povol vytvranie a mazanie indexov.';
 $strPrivDescInsert = 'Povol vkladanie a nahradzovanie dt.';
 $strPrivDescLockTables = 'Povol zmaknutie tabuliek pre aktulne vlkno.';
 $strPrivDescMaxConnections = 'Obmedz poet novch spojen, ktor me pouvate vytvori za hodinu.';
-$strPrivDescMaxQuestions = 'Obmedz poet dotazov, ktor me pouvate odosla za hodinu.';
+$strPrivDescMaxQuestions = 'Obmedz poet dopytov, ktor me pouvate odosla za hodinu.';
 $strPrivDescMaxUpdates = 'Obmedz poet prkazov meniacich tabuku alebo databzu, ktor me pouvate odosla za hodinu.';
-$strPrivDescMaxUserConnections = 'Obmedzuje poet simultnnych pripojen uvatea.';
+$strPrivDescMaxUserConnections = 'Obmedzuje poet simultnnych pripojen pouvatea.';
 $strPrivDescProcess3 = 'Povol zabjanie procesov inm pouvatelom.';
-$strPrivDescProcess4 = 'Povol prezeranie kompletnch dotazov v zozname procesov.';
+$strPrivDescProcess4 = 'Povol prezeranie kompletnch dopytov v zozname procesov.';
 $strPrivDescReferences = 'Nefunguje v tejto verzii MySQL.';
 $strPrivDescReload = 'Povol znovunatanie nastaven a vyprzdovanie vyrovnvacch pamt serveru.';
 $strPrivDescReplClient = 'Povol pouvateovi zisti kde je hlavn / pomocn server.';
@@ -576,20 +608,24 @@ $strPrivDescUpdate = 'Povol menenie dt.';
 $strPrivDescUsage = 'iadne prva.';
 $strPrivileges = 'Oprvnenia';
 $strPrivilegesReloaded = 'Prva boli spene znovunatan.';
+$strProcedures = 'Procedry';
+$strProcesses = 'Procesy';
 $strProcesslist = 'Zoznam procesov';
+$strProtocolVersion = 'Verzia protokolu';
 $strPutColNames = 'Prida nzvy pol na prv riadok';
 
 $strQBEDel = 'Zmaza';
-$strQBE = 'Dotaz poda prkladu';
+$strQBE = 'Dopyt poda prkladu';
 $strQBEIns = 'Vloi';
 $strQueryCache = 'Vyrovnvacia pam prkazov';
 $strQueryFrame = 'SQL okno';
-$strQueryOnDb = ' SQL dotaz v databze <b>%s</b>:';
+$strQueryOnDb = ' SQL dopyt v databze <b>%s</b>:';
+$strQueryResultsOperations = 'Opercie s vsledkami dopytu';
 $strQuerySQLHistory = 'SQL histria';
 $strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
-$strQueryTime = 'Dotaz zabral %01.4f sek.';
-$strQueryType = 'Typ dotazu';
-$strQueryWindowLock = 'Neprepisova tento dotaz z hlavnho okna';
+$strQueryTime = 'Dopyt zabral %01.4f sek.';
+$strQueryType = 'Typ dopytu';
+$strQueryWindowLock = 'Neprepisova tento dopyt z hlavnho okna';
 
 $strReadRequests = 'Poiadavkov na tanie';
 $strReceived = 'Prijat';
@@ -598,11 +634,11 @@ $strReferentialIntegrity = 'Skontrolova referenn integritu:';
 $strRefresh = 'Obnovi';
 $strRelationalSchema = 'Relan schma';
 $strRelationNotWorking = 'Prdavn vlastnosti pre prcu s prepojenmi tabukami boli deaktivovan. Ak chcete zisti preo, kliknite %ssem%s.';
-$strRelationsForTable = 'VZAHY PRE TABUKU';
+$strRelationsForTable = 'PREPOJENIA PRE TABUKU';
 $strRelations = 'Prepojenia';
-$strRelationView = 'Zobrazi spojitosti';
+$strRelationView = 'Zobrazi prepojenia';
 $strReloadingThePrivileges = 'Znovunatanie prv';
-$strReloadMySQL = 'Znovu-nata MySQL';
+$strReloadPrivileges = 'Znovunata prstupov prva';
 $strRemoveSelectedUsers = 'Odstrni vybranch pouvateov';
 $strRenameDatabaseOK = 'Databza %s bola premenovan na %s';
 $strRenameTableOK = 'Tabuka %s bola premenovan na %s';
@@ -629,9 +665,9 @@ $strRowsModeVertical = 'vertiklnom';
 $strRows = 'Riadkov';
 $strRowsStatistic = 'tatistika riadku';
 $strRunning = 'be na %s';
-$strRunQuery = 'Odoli dotaz';
+$strRunQuery = 'Odoli dopyt';
 $strRunSQLQueryOnServer = 'Spusti SQL prkaz(y) na servri %s';
-$strRunSQLQuery = 'Spusti SQL dotaz/dotazy na databzu %s';
+$strRunSQLQuery = 'Spusti SQL dopyt/dopyty na databzu %s';
 $strRussian = 'Rutina';
 
 $strSaveOnServer = 'Uloi na server do adresra %s';
@@ -652,17 +688,17 @@ $strSelectADb = 'Prosm vyberte si databzu';
 $strSelectAll = 'Oznai vetko';
 $strSelectBinaryLog = 'Vyberte binrny log na zobrazenie';
 $strSelectFields = 'Zvoli pole (najmenej jedno):';
-$strSelectNumRows = 'v dotaze';
+$strSelectNumRows = 'v dopyte';
 $strSelectTables = 'Vybra Tabuky';
 $strSend = 'Poli';
 $strSent = 'Odoslan';
 $strServerChoice = 'Voba serveru';
 $strServerNotResponding = 'Server neodpoved';
 $strServer = 'Server';
+$strServers = 'Servery';
 $strServerStatusDelayedInserts = 'Odloen vloenia';
 $strServerStatus = 'Stav serveru';
 $strServerStatusUptime = 'Tento server be %s. Bol spusten %s.';
-$strServerTabProcesslist = 'Procesy';
 $strServerTabVariables = 'Premenn';
 $strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.';
 $strServerVars = 'Premenn a nastavenia serveru';
@@ -672,7 +708,7 @@ $strSetEnumVal = 'Ak je pole typu "enum" alebo "set", prosm zadvajte hodnoty v t
 $strShowAll = 'Zobrazi vetko';
 $strShowColor = 'Zobrazi farbu';
 $strShowDatadictAs = 'Formt dtovho slovnka';
-$strShowFullQueries = 'Zobrazi kompletn dotazy';
+$strShowFullQueries = 'Zobrazi kompletn dopyty';
 $strShowGrid = 'Zobrazi mrieku';
 $strShowingBookmark = 'Zobrazujem obben prkaz';
 $strShowingRecords = 'Ukza zznamy ';
@@ -789,7 +825,7 @@ $strShowStatusThreads_createdDescr = 'Poet vlkien vytvorench na zaobchdzanie so
 $strShowStatusThreads_runningDescr = 'Poet aktvnych (nespiacich) vlkien.';
 $strShowTableDimension = 'Zobrazi rozmery tabuliek';
 $strShowTables = 'Zobrazi tabuky';
-$strShowThisQuery = ' Zobrazi tento dotaz znovu ';
+$strShowThisQuery = ' Zobrazi tento dopyt znovu ';
 $strShow = 'Ukza';
 $strSimplifiedChinese = 'Zjednoduen ntina';
 $strSingly = '(po jednom)';
@@ -804,12 +840,13 @@ $strSort = 'Triedi';
 $strSpaceUsage = 'Zabran miesto';
 $strSpanish = 'panielsky';
 $strSplitWordsWithSpace = 'Slov s rozdelen medzerou (" ").';
-$strSQLExportCompatibility = 'Kompatibilita SQL exportu';
-$strSQLExportType = 'Typ vytvorench dotazov';
-$strSQLOptions = 'SQL nastavenia';
-$strSQLParserBugMessage = 'Je mon, e ste nali chybu v SQL syntaktickom analyztore. Preskmajte podrobne SQL dotaz, predovetkm sprvnos umiestnenia vodzoviek. alia monos je, e nahrvate sbor s binrnymi dtami nezapsanmi v vodzovkch. Mete tie vyska poui prkazov riadok MySQL na odstrnenie problmu. Pokial stle mte problmy alebo syntaktick analyztor SQL stle hlsi chybu v dotaze, ktor v prkazovom riadku funguje, prosm pokste sa zredukova dotaz na o najmen, v ktorom sa problm ete vyskytuje a ohlste chybu na strnke phpMyAdmina spolu so sekciou VPIS uveden niie:';
-$strSQLParserUserError = 'Vyskytla sa chyba v SQL dotaze. Niie uveden MySQL vstup (ak je nejak) Vm me pomc odstrni problm';
-$strSQLQuery = 'SQL dotaz';
+$strSQLCompatibility = 'Reim kompatibility SQL';
+$strSQLExportType = 'Typ vytvorench dopytov';
+$strSQLImportOptions = 'Nastavenia SQL importu';
+$strSQLOptions = 'Nastavenia pre SQL';
+$strSQLParserBugMessage = 'Je mon, e ste nali chybu v SQL syntaktickom analyztore. Preskmajte podrobne SQL dopyt, predovetkm sprvnos umiestnenia vodzoviek. alia monos je, e nahrvate sbor s binrnymi dtami nezapsanmi v vodzovkch. Mete tie vyska poui prkazov riadok MySQL na odstrnenie problmu. Pokial stle mte problmy alebo syntaktick analyztor SQL stle hlsi chybu v dopyte, ktor v prkazovom riadku funguje, prosm pokste sa zredukova dopyt na o najmen, v ktorom sa problm ete vyskytuje a ohlste chybu na strnke phpMyAdmina spolu so sekciou VPIS uveden niie:';
+$strSQLParserUserError = 'Vyskytla sa chyba v SQL dopyte. Niie uveden MySQL vstup (ak je nejak) Vm me pomc odstrni problm';
+$strSQLQuery = 'SQL dopyt';
 $strSQLResult = 'vsledok SQL';
 $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Neplatn identifiktor';
@@ -818,20 +855,21 @@ $strSQPBugUnknownPunctuation = 'Neznmy interpunkn reazec';
 $strStatCheckTime = 'Posledn kontrola';
 $strStatCreateTime = 'Vytvorenie';
 $strStatement = 'daj';
+$strStatisticsOverrun = 'Na vyaenom serveri me djs k preteeniu potadiel, take tatistiky servera mu by nepresn.';
 $strStatUpdateTime = 'Posledn zmena';
 $strStatus = 'Stav';
-$strStorageEngine = 'lon Systm';
 $strStorageEngines = 'lon Systmy';
+$strStorageEngine = 'lon Systm';
 $strStrucCSV = 'CSV dta';
 $strStrucData = 'truktru a dta';
-$strStrucDrop = 'Pridaj \'vyma tabuku\'';
 $strStrucExcelCSV = 'CSV pre MS Excel dta';
 $strStrucNativeExcel = 'Natvne dta MS Excel';
+$strStrucNativeExcelOptions = 'Nastavenia pre natvny Excel';
 $strStrucOnly = 'Iba truktru';
 $strStructPropose = 'Navrhn truktru tabuky';
 $strStructure = 'truktra';
 $strSubmit = 'Odoli';
-$strSuccess = 'SQL dotaz bol spene vykonan';
+$strSuccess = 'SQL dopyt bol spene vykonan';
 $strSum = 'Celkom';
 $strSwedish = 'vdsky';
 $strSwitchToDatabase = 'Prepn na skoprovan databzu';
@@ -849,12 +887,16 @@ $strTableOptions = 'Parametre tabuky';
 $strTables = '%s tabuka(y)';
 $strTableStructure = 'truktra tabuky pre tabuku';
 $strTable = 'Tabuka';
-$strTableType = 'Typ tabuky';
 $strTakeIt = 'zvoli';
 $strTblPrivileges = 'Oprvnenia pre jednotliv tabuky';
 $strTempData = 'Doasn dta';
 $strTextAreaLength = ' Toto mono nepjde upravi,<br /> kvli svojej dke ';
 $strThai = 'Thajina';
+$strThemeDefaultNotFound = 'Predvolen vzhad %s nebol njden!';
+$strThemeNoPreviewAvailable = 'Nhad nie je dostupn.';
+$strThemeNotFound = 'Vzhad %s nebol njden!';
+$strThemeNoValidImgPath = 'Nebola njden platn cesta k obrzkom pre vzhad %s!';
+$strThemePathNotFound = 'Nebola njden platn cesta ku vzhadu %s!';
 $strTheme = 'Vzhad';
 $strThisHost = 'Tento pota';
 $strThisNotDirectory = 'Nebol zadan adresr';
@@ -872,7 +914,7 @@ $strTraditionalSpanish = 'Tradin panielina';
 $strTraffic = 'Prevdzka';
 $strTransactionCoordinator = 'Koordintor transakci';
 $strTransformation_application_octetstream__download = 'Zobraz odkaz na stiahnutie dt. Prv parameter je meno sboru, druh je meno stpca v tabuke obsahujci meno sboru. Ak zadte druh parameter, prv mus by przdny.';
-$strTransformation_application_octetstream__hex = 'Zobraz dta v ich hexadecimlnej forme.';
+$strTransformation_application_octetstream__hex = 'Zobraz dta v ich hexadecimlnej forme. Nepovinn parameter uruje po koko znakoch je vkladan medzera (tandardne po dvoch).';
 $strTransformation_image_jpeg__inline = 'Zobraz nhad obrzku s odkazom na obrzok; parametre rka a vka v bodoch (pomer strn obrzku zostane zachovan)';
 $strTransformation_image_jpeg__link = 'Zobraz odkaz na obrzok (napr. stiahnutie poa blob).';
 $strTransformation_image_png__inline = 'Zobraz image/jpeg: inline';
@@ -883,7 +925,7 @@ $strTransformation_text_plain__imagelink = 'Zobraz obrzok a odkaz z poa obsahujc
 $strTransformation_text_plain__link = 'Zobraz odkaz z poa obsahujceho odkaz. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh parameter je text odkazu.';
 $strTransformation_text_plain__sql = 'Formtuje text ako SQL prkaz pomocou syntaxovho zvrazovania.';
 $strTransformation_text_plain__substr = 'Zobraz iba as reazca. Prv parameter je posun od zaiatku (predvolen je 0) a druh uruje dku textu, ktor sa ma zobrazi, ak nie je zadan bude zobrazen zvyok textu. Tret parameter uruje znaky, ktor bud pridan na koniec skrtenho textu (predvolen je ...).';
-$strTruncateQueries = 'Zobrazi skrtene dotazy';
+$strTruncateQueries = 'Zobrazi skrtene dopyty';
 $strTurkish = 'Turecky';
 $strType = 'Typ';
 
@@ -896,20 +938,22 @@ $strUnselectAll = 'Odznai vetko';
 $strUnsupportedCompressionDetected = 'Poksili ste sa nata sbor s nepodporovanou kompresiou (%s). Bu nie je zahrnut podpora tejto kompresie alebo bola deaktivovan v konfigurcii.';
 $strUpdatePrivMessage = 'Boli aktualizovan oprvnenia pre %s.';
 $strUpdateProfileMessage = 'Profil bol aktualizovan.';
-$strUpdateQuery = 'Aktualizova dotaz';
+$strUpdateQuery = 'Aktualizova dopyt';
 $strUpdComTab = 'Prosm pretajte si dokumentciu ako aktualizova tabuku s informciami o stpcoch (Column_comments Table)';
 $strUpgrade = 'Mali by ste aktualizova %s na verziu %s alebo vyiu.';
 $strUploadLimit = 'Pravdepodobne ste sa poksili uploadnu prli vek sbor. Pretajte si prosm %sdokumentciu%s, ako sa d toto obmedzenie obs.';
+$strUploadsNotAllowed = 'Ukladanie sborov na server nie je povolen.';
 $strUsage = 'Vyuitie';
 $strUseBackquotes = ' Poui opan apostrof pri nzvoch tabuliek a pol ';
+$strUsedPhpExtensions = 'Pouit rozrenia PHP';
 $strUseHostTable = 'Poui tabuku s hostitemi';
 $strUserAlreadyExists = 'Pouvate %s u existuje!';
 $strUserEmpty = 'Meno pouvatea je przdne!';
 $strUserName = 'Meno pouvatea';
 $strUserNotFound = 'Zvolen pouvate nebol njden v tabuke prv.';
-$strUserOverview = 'Prehad uvatelov';
+$strUserOverview = 'Prehad pouvatelov';
 $strUser = 'Pouvate';
-$strUsersDeleted = 'Vybran uvatelia bol spene odstrnen.';
+$strUsersDeleted = 'Vybran pouvatelia bol spene odstrnen.';
 $strUsersHavingAccessToDb = 'Pouvatelia majci prstup k &quot;%s&quot;';
 $strUseTabKey = 'Pre pohyb medzi hodnotami pouite klvesu TAB alebo pre pohyb vetkmi smermi klvesy CTRL+pky';
 $strUseTables = 'Poui tabuky';
@@ -924,8 +968,9 @@ $strVersionInformation = 'Informcie o verzii';
 $strViewDumpDatabases = 'Export databz';
 $strViewDumpDB = 'Zobrazi dump (schmu) databzy';
 $strViewDump = 'Zobrazi dump (schmu) tabuky';
-$strViewHasBeenDropped = 'Nhad %s bol odstrnen';
-$strView = 'Nhad';
+$strViewHasBeenDropped = 'Pohad %s bol odstrnen';
+$strViewMaxExactCount = 'Tento pohad obsahuje viac ako %s riadkov. Vi %sdokumentcia%s.';
+$strView = 'Pohad';
 
 $strWebServerUploadDirectoryError = 'Adresr uren pre upload sborov sa ned otvori';
 $strWebServerUploadDirectory = 'upload adresr web serveru';
@@ -939,41 +984,18 @@ $strWritingCommentNotPossible = 'Komentr sa ned zapsa';
 $strWritingRelationNotPossible = 'Vzah sa ned zapsa';
 $strWrongUser = 'Zl pouvatesk meno alebo heslo. Prstup zamietnut.';
 
+$strXMLOptions = 'Nastavenia pre XML';
 $strXML = 'XML';
 
 $strYes = 'no';
 
 $strZeroRemovesTheLimit = 'Poznmka: Nastavenie tchto parametrov na 0 (nulu) odstrni obmedzenia.';
-$strZip = '"zo zipovan"';
+$strZip = '"zozipovan"';
 
-$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
-$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
-$strFileNameTemplateDescriptionTable = 'table name';  //to translate
-$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
-$strFileNameTemplateDescriptionServer = 'server name';  //to translate
-$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
-$strProtocolVersion = 'Protocol version';  //to translate
-$strMysqlClientVersion = 'MySQL client version';  //to translate
-$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
-$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
-$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
-$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
-$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
-$strPDF = 'PDF';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
-$strPDFReportTitle = 'Report title';  //to translate
-$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
-$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
-$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
-$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strThemeNotFound = 'Theme %s not found!';  //to translate
-$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
-$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
-$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
-$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
-$strBrowseDistinctValues = 'Browse distinct values';  //to translate
-$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
-$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
+// To translate:
+
+$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
+
+$strFontSize = 'Font size';  //to translate
+$strLanguage = 'Language';  //to translate
 ?>
